@@ -1,5 +1,5 @@
 /* Formatted output to strings in C locale.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2023 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,6 +16,9 @@
 
 #include <config.h>
 
+/* Specification.  */
+#include "c-vasnprintf.h"
+
 #include <string.h>
 
 #include "printf-parse.h"
