@@ -101,8 +101,8 @@ case_map_execute (const struct case_map *map, struct ccase *src)
       for (dst_idx = 0; dst_idx < n_values; dst_idx++)
         {
           int src_idx = map->map[dst_idx];
-          if (src_idx != -1)
-	    value_copy (case_data_rw_idx (dst, dst_idx), case_data_idx (src, src_idx), caseproto_get_width (map->proto, dst_idx));
+          assert (src_idx != -1);
+          value_copy (case_data_rw_idx (dst, dst_idx), case_data_idx (src, src_idx), caseproto_get_width (map->proto, dst_idx));
         }
       case_unref (src);
       return dst;
@@ -131,11 +131,14 @@ struct casereader *
 case_map_create_input_translator (struct case_map *map,
                                   struct casereader *subreader)
 {
-    return casereader_create_translator (subreader,
+  if (!map)
+    return casereader_rename (subreader);
+  static const struct casereader_translator_class class = {
+    translate_case, destroy_case_map,
+  };
+  return casereader_translate_stateless (subreader,
                                          case_map_get_proto (map),
-                                         translate_case,
-                                         destroy_case_map,
-                                         map);
+                                         &class, map);
 }
 
 /* Creates and returns a new casewriter.  Cases written to the
@@ -151,11 +154,13 @@ struct casewriter *
 case_map_create_output_translator (struct case_map *map,
                                    struct casewriter *subwriter)
 {
-    return casewriter_create_translator (subwriter,
-                                         case_map_get_proto (map),
-                                         translate_case,
-                                         destroy_case_map,
-                                         map);
+  if (!map)
+    return casewriter_rename (subwriter);
+  return casewriter_create_translator (subwriter,
+                                       case_map_get_proto (map),
+                                       translate_case,
+                                       destroy_case_map,
+                                       map);
 }
 
 /* Casereader/casewriter translation callback. */
@@ -174,43 +179,6 @@ destroy_case_map (void *map_)
   case_map_destroy (map);
   return true;
 }
-
-/* Creates and returns a case_map that can be used to compact
-   cases for dictionary D.
-
-   Compacting a case eliminates "holes" between values and after
-   the last value.  (Holes are created by deleting variables.)
-
-   All variables are compacted if EXCLUDE_CLASSES is 0, or it may
-   contain one or more of (1u << DC_ORDINARY), (1u << DC_SYSTEM),
-   or (1u << DC_SCRATCH) to cause the corresponding type of
-   variable to be deleted during compaction. */
-struct case_map *
-case_map_to_compact_dict (const struct dictionary *d,
-                          unsigned int exclude_classes)
-{
-  size_t n_vars = dict_get_n_vars (d);
-  struct caseproto *proto;
-  struct case_map *map;
-  size_t n_values;
-  size_t i;
-
-  /* Create the case mapping. */
-  proto = dict_get_compacted_proto (d, exclude_classes);
-  map = create_case_map (proto);
-  caseproto_unref (proto);
-
-  /* Add the values to the case mapping. */
-  n_values = 0;
-  for (i = 0; i < n_vars; i++)
-    {
-      struct variable *v = dict_get_var (d, i);
-      if (!(exclude_classes & (1u << var_get_dict_class (v))))
-        insert_mapping (map, var_get_case_index (v), n_values++);
-    }
-
-  return map;
-}
 
 struct stage_var
   {
@@ -222,12 +190,15 @@ struct stage_var
 struct case_map_stage
   {
     const struct dictionary *dict;
-    struct hmap stage_vars;
+    struct hmap stage_vars_by_pointer;
+
+    struct stage_var *stage_vars;
+    size_t n_stage_vars;
   };
 
 /* Prepares and returns a "struct case_map_stage" for producing a case map for
    DICT.  Afterward, the caller may delete, reorder, or rename variables within
-   DICT at will before using case_map_stage_get_case_map() to produce the case
+   DICT at will before using case_map_stage_to_case_map() to produce the case
    map.
 
    The caller must *not* add new variables to DICT. */
@@ -235,22 +206,23 @@ struct case_map_stage *
 case_map_stage_create (const struct dictionary *dict)
 {
   size_t n_vars = dict_get_n_vars (dict);
-  struct case_map_stage *stage;
-  size_t i;
+  struct case_map_stage *stage = xmalloc (sizeof *stage);
+  *stage = (struct case_map_stage) {
+    .dict = dict,
+    .stage_vars_by_pointer = HMAP_INITIALIZER (stage->stage_vars_by_pointer),
+    .stage_vars = xnmalloc (n_vars, sizeof *stage->stage_vars),
+    .n_stage_vars = n_vars,
+  };
 
-  stage = xmalloc (sizeof *stage);
-  stage->dict = dict;
-  hmap_init (&stage->stage_vars);
-
-  for (i = 0; i < n_vars; i++)
+  for (size_t i = 0; i < n_vars; i++)
     {
       const struct variable *var = dict_get_var (dict, i);
-      struct stage_var *stage_var;
-
-      stage_var = xmalloc (sizeof *stage_var);
-      stage_var->var = var;
-      stage_var->case_index = var_get_case_index (var);
-      hmap_insert (&stage->stage_vars, &stage_var->hmap_node,
+      struct stage_var *stage_var = &stage->stage_vars[i];
+      *stage_var = (struct stage_var) {
+        .var = var,
+        .case_index = var_get_dict_index (var),
+      };
+      hmap_insert (&stage->stage_vars_by_pointer, &stage_var->hmap_node,
                    hash_pointer (var, 0));
     }
 
@@ -263,15 +235,8 @@ case_map_stage_destroy (struct case_map_stage *stage)
 {
   if (stage != NULL)
     {
-      struct stage_var *stage_var, *next_stage_var;
-
-      HMAP_FOR_EACH_SAFE (stage_var, next_stage_var,
-                          struct stage_var, hmap_node, &stage->stage_vars)
-        {
-          hmap_delete (&stage->stage_vars, &stage_var->hmap_node);
-          free (stage_var);
-        }
-      hmap_destroy (&stage->stage_vars);
+      hmap_destroy (&stage->stage_vars_by_pointer);
+      free (stage->stage_vars);
       free (stage);
     }
 }
@@ -283,7 +248,7 @@ case_map_stage_find_var (const struct case_map_stage *stage,
   const struct stage_var *stage_var;
 
   HMAP_FOR_EACH_IN_BUCKET (stage_var, struct stage_var, hmap_node,
-                           hash_pointer (var, 0), &stage->stage_vars)
+                           hash_pointer (var, 0), &stage->stage_vars_by_pointer)
     if (stage_var->var == var)
       return stage_var;
 
@@ -295,31 +260,22 @@ case_map_stage_find_var (const struct case_map_stage *stage,
   NOT_REACHED ();
 }
 
-/* Produces a case map from STAGE, which must have been previously created with
-   case_map_stage_create().  The case map maps from the original case index of
-   the variables in STAGE's dictionary to their current case indexes.
-
-   Returns the new case map, or a null pointer if no mapping is required (that
-   is, no data has changed position). */
-struct case_map *
+static struct case_map *
 case_map_stage_get_case_map (const struct case_map_stage *stage)
 {
-  struct case_map *map;
   size_t n_vars = dict_get_n_vars (stage->dict);
-  size_t n_values;
-  size_t i;
-  bool identity_map = true;
+  bool identity_map = n_vars == stage->n_stage_vars;
 
-  map = create_case_map (dict_get_proto (stage->dict));
-  for (i = 0; i < n_vars; i++)
+  struct case_map *map = create_case_map (dict_get_proto (stage->dict));
+  for (size_t i = 0; i < n_vars; i++)
     {
       const struct variable *var = dict_get_var (stage->dict, i);
       const struct stage_var *stage_var = case_map_stage_find_var (stage, var);
 
-      if (var_get_case_index (var) != stage_var->case_index)
+      if (var_get_dict_index (var) != stage_var->case_index)
         identity_map = false;
 
-      insert_mapping (map, stage_var->case_index, var_get_case_index (var));
+      insert_mapping (map, stage_var->case_index, var_get_dict_index (var));
     }
 
   if (identity_map)
@@ -328,10 +284,22 @@ case_map_stage_get_case_map (const struct case_map_stage *stage)
       return NULL;
     }
 
-  n_values = caseproto_get_n_widths (map->proto);
-  while (n_values > 0 && caseproto_get_width (map->proto, n_values - 1) == -1)
-    map->proto = caseproto_remove_widths (map->proto, --n_values, 1);
+  return map;
+}
 
+/* Produces a case map from STAGE, which must have been previously created with
+   case_map_stage_create().  The case map maps from the original case index of
+   the variables in STAGE's dictionary to their current case indexes.
+
+   Returns the new case map, or a null pointer if no mapping is required (that
+   is, no variables were deleted or reordered).
+
+   Destroys STAGE. */
+struct case_map *
+case_map_stage_to_case_map (struct case_map_stage *stage)
+{
+  struct case_map *map = case_map_stage_get_case_map (stage);
+  case_map_stage_destroy (stage);
   return map;
 }
 
@@ -350,7 +318,7 @@ case_map_by_name (const struct dictionary *old,
       struct variable *nv = dict_get_var (new, i);
       struct variable *ov = dict_lookup_var_assert (old, var_get_name (nv));
       assert (var_get_width (nv) == var_get_width (ov));
-      insert_mapping (map, var_get_case_index (ov), var_get_case_index (nv));
+      insert_mapping (map, var_get_dict_index (ov), var_get_dict_index (nv));
     }
   return map;
 }
