@@ -32,7 +32,6 @@ struct casewriter;
 struct ccase;
 struct dictionary;
 
-struct case_map *case_map_create (void);
 void case_map_destroy (struct case_map *);
 struct ccase *case_map_execute (const struct case_map *, struct ccase *);
 
@@ -47,11 +46,7 @@ struct casewriter *case_map_create_output_translator (struct case_map *,
    a modified version of the same dictionary. */
 struct case_map_stage *case_map_stage_create (const struct dictionary *);
 void case_map_stage_destroy (struct case_map_stage *);
-struct case_map *case_map_stage_get_case_map (const struct case_map_stage *);
-
-/* For eliminating "holes" in a case. */
-struct case_map *case_map_to_compact_dict (const struct dictionary *d,
-                                           unsigned int exclude_classes);
+struct case_map *case_map_stage_to_case_map (struct case_map_stage *);
 
 /* For mapping cases for one dictionary to another based on
    variable names within the dictionary. */
