@@ -33,9 +33,7 @@
 struct casereader_translator
   {
     struct casereader *subreader; /* Source of input cases. */
-
-    struct ccase *(*translate) (struct ccase *input, void *aux);
-    bool (*destroy) (void *aux);
+    const struct casereader_translator_class *class;
     void *aux;
   };
 
@@ -63,18 +61,17 @@ static const struct casereader_class casereader_translator_class;
 struct casereader *
 casereader_create_translator (struct casereader *subreader,
                               const struct caseproto *output_proto,
-                              struct ccase *(*translate) (struct ccase *input,
-                                                          void *aux),
-                              bool (*destroy) (void *aux),
+                              const struct casereader_translator_class *class,
                               void *aux)
 {
   struct casereader_translator *ct = xmalloc (sizeof *ct);
-  struct casereader *reader;
-  ct->subreader = casereader_rename (subreader);
-  ct->translate = translate;
-  ct->destroy = destroy;
-  ct->aux = aux;
-  reader = casereader_create_sequential (
+  *ct = (struct casereader_translator) {
+    .subreader = casereader_rename (subreader),
+    .class = class,
+    .aux = aux,
+  };
+
+  struct casereader *reader = casereader_create_sequential (
     NULL, output_proto, casereader_get_n_cases (ct->subreader),
     &casereader_translator_class, ct);
   taint_propagate (casereader_get_taint (ct->subreader),
@@ -90,7 +87,7 @@ casereader_translator_read (struct casereader *reader UNUSED,
   struct casereader_translator *ct = ct_;
   struct ccase *tmp = casereader_read (ct->subreader);
   if (tmp)
-    tmp = ct->translate (tmp, ct->aux);
+    tmp = ct->class->translate (tmp, ct->aux);
   return tmp;
 }
 
@@ -100,7 +97,7 @@ casereader_translator_destroy (struct casereader *reader UNUSED, void *ct_)
 {
   struct casereader_translator *ct = ct_;
   casereader_destroy (ct->subreader);
-  ct->destroy (ct->aux);
+  ct->class->destroy (ct->aux);
   free (ct);
 }
 
@@ -122,9 +119,7 @@ struct casereader_stateless_translator
     struct casereader *subreader; /* Source of input cases. */
 
     casenumber case_offset;
-    struct ccase *(*translate) (struct ccase *input, casenumber,
-                                const void *aux);
-    bool (*destroy) (void *aux);
+    const struct casereader_translator_class *class;
     void *aux;
   };
 
@@ -142,10 +137,6 @@ casereader_stateless_translator_class;
    cases may be skipped and never retrieved at all.  If TRANSLATE is stateful,
    use casereader_create_translator instead.
 
-   The casenumber argument to the TRANSLATE function is the absolute case
-   number in SUBREADER, that is, 0 when the first case in SUBREADER is being
-   translated, 1 when the second case is being translated, and so on.
-
    The cases returned by TRANSLATE must match OUTPUT_PROTO.
 
    When the stateless translating casereader is destroyed, DESTROY will be
@@ -158,18 +149,16 @@ struct casereader *
 casereader_translate_stateless (
   struct casereader *subreader,
   const struct caseproto *output_proto,
-  struct ccase *(*translate) (struct ccase *input, casenumber,
-                              const void *aux),
-  bool (*destroy) (void *aux),
+  const struct casereader_translator_class *class,
   void *aux)
 {
   struct casereader_stateless_translator *cst = xmalloc (sizeof *cst);
-  struct casereader *reader;
-  cst->subreader = casereader_rename (subreader);
-  cst->translate = translate;
-  cst->destroy = destroy;
-  cst->aux = aux;
-  reader = casereader_create_random (
+  *cst = (struct casereader_stateless_translator) {
+    .subreader = casereader_rename (subreader),
+    .class = class,
+    .aux = aux,
+  };
+  struct casereader *reader = casereader_create_random (
     output_proto, casereader_get_n_cases (cst->subreader),
     &casereader_stateless_translator_class, cst);
   taint_propagate (casereader_get_taint (cst->subreader),
@@ -185,7 +174,7 @@ casereader_stateless_translator_read (struct casereader *reader UNUSED,
   struct casereader_stateless_translator *cst = cst_;
   struct ccase *tmp = casereader_peek (cst->subreader, idx);
   if (tmp != NULL)
-    tmp = cst->translate (tmp, cst->case_offset + idx, cst->aux);
+    tmp = cst->class->translate (tmp, cst->aux);
   return tmp;
 }
 
@@ -196,7 +185,7 @@ casereader_stateless_translator_destroy (struct casereader *reader UNUSED,
 {
   struct casereader_stateless_translator *cst = cst_;
   casereader_destroy (cst->subreader);
-  cst->destroy (cst->aux);
+  cst->class->destroy (cst->aux);
   free (cst);
 }
 
@@ -243,8 +232,8 @@ static struct ccase *can_translate (struct ccase *, void *can_);
    when the translating casereader is destroyed. */
 struct casereader *
 casereader_create_append_numeric (struct casereader *subreader,
-				  new_value_func func, void *aux,
-				  void (*destroy) (void *aux))
+                                  new_value_func func, void *aux,
+                                  void (*destroy) (void *aux))
 {
   struct casereader_append_numeric *can = xmalloc (sizeof *can);
   can->proto = caseproto_ref (casereader_get_proto (subreader));
@@ -253,8 +242,11 @@ casereader_create_append_numeric (struct casereader *subreader,
   can->aux = aux;
   can->func = func;
   can->destroy = destroy;
-  return casereader_create_translator (subreader, can->proto,
-                                       can_translate, can_destroy, can);
+
+  static const struct casereader_translator_class class = {
+    can_translate, can_destroy,
+  };
+  return casereader_create_translator (subreader, can->proto, &class, can);
 }
 
 
@@ -289,8 +281,8 @@ struct arithmetic_sequence
 
 static double
 next_arithmetic (const struct ccase *c UNUSED,
-		 casenumber n,
-		 void *aux)
+                 casenumber n,
+                 void *aux)
 {
   struct arithmetic_sequence *as = aux;
   return n * as->increment + as->first;
@@ -313,7 +305,7 @@ casereader_create_arithmetic_sequence (struct casereader *subreader,
   as->first = first;
   as->increment = increment;
   return casereader_create_append_numeric (subreader, next_arithmetic,
-					   as, free);
+                                           as, free);
 }
 
 
@@ -364,12 +356,12 @@ static struct ccase *car_translate (struct ccase *input, void *car_);
    when the translating casereader is destroyed. */
 struct casereader *
 casereader_create_append_rank (struct casereader *subreader,
-			       const struct variable *v,
-			       const struct variable *w,
-			       enum rank_error *err,
-			       distinct_func *distinct_callback,
-			       void *aux
-			)
+                               const struct variable *v,
+                               const struct variable *w,
+                               enum rank_error *err,
+                               distinct_func *distinct_callback,
+                               void *aux
+                        )
 {
   struct casereader_append_rank *car = xmalloc (sizeof *car);
   car->proto = caseproto_ref (casereader_get_proto (subreader));
@@ -385,8 +377,10 @@ casereader_create_append_rank (struct casereader *subreader,
   car->err = err;
   car->prev_value = SYSMIS;
 
-  return casereader_create_translator (subreader, car->proto,
-                                       car_translate, car_destroy, car);
+  static const struct casereader_translator_class class = {
+    car_translate, car_destroy
+  };
+  return casereader_create_translator (subreader, car->proto, &class, car);
 }
 
 
@@ -410,7 +404,7 @@ car_translate (struct ccase *input, void *car_)
   if (car->prev_value != SYSMIS)
     {
       if (car->err && value < car->prev_value)
-	*car->err |= RANK_ERR_UNSORTED;
+        *car->err |= RANK_ERR_UNSORTED;
     }
 
   if (car->n_common == 1)
@@ -419,42 +413,42 @@ car_translate (struct ccase *input, void *car_)
       casenumber k = 0;
       double weight = 1.0;
       if (car->weight)
-	{
-	  weight = case_num (input, car->weight);
-	  if (car->err && weight < 0)
-	    *car->err |= RANK_ERR_NEGATIVE_WEIGHT;
-	}
+        {
+          weight = case_num (input, car->weight);
+          if (car->err && weight < 0)
+            *car->err |= RANK_ERR_NEGATIVE_WEIGHT;
+        }
 
       do
-	{
-	  struct ccase *c = casereader_peek (car->clone, car->n + ++k);
-	  if (c == NULL)
-	    break;
-	  vxx = case_num (c, car->var);
+        {
+          struct ccase *c = casereader_peek (car->clone, car->n + ++k);
+          if (c == NULL)
+            break;
+          vxx = case_num (c, car->var);
 
-	  if (vxx == value)
-	    {
-	      if (car->weight)
-		{
-		  double w = case_num (c, car->weight);
+          if (vxx == value)
+            {
+              if (car->weight)
+                {
+                  double w = case_num (c, car->weight);
 
-		  if (car->err && w < 0)
-		    *car->err |= RANK_ERR_NEGATIVE_WEIGHT;
+                  if (car->err && w < 0)
+                    *car->err |= RANK_ERR_NEGATIVE_WEIGHT;
 
-		  weight += w;
-		}
-	      else
-		weight += 1.0;
-	      car->n_common++;
-	    }
+                  weight += w;
+                }
+              else
+                weight += 1.0;
+              car->n_common++;
+            }
           case_unref (c);
-	}
+        }
       while (vxx == value);
       car->mean_rank = car->cc + (weight + 1) / 2.0;
       car->cc += weight;
 
       if (car->distinct)
-	car->distinct (value, car->n_common, weight, car->aux);
+        car->distinct (value, car->n_common, weight, car->aux);
     }
   else
     car->n_common--;
@@ -501,12 +495,12 @@ uniquify (const struct ccase *c, void *aux)
       goto end;
 
   dir = value_compare_3way (case_data (next_case, cdr->key),
-			    current_value, key_width);
+                            current_value, key_width);
   if (dir > 0)
     dir = 1;
   if (dir < 0)
     dir = -1;
-      
+
   case_unref (next_case);
   if (dir != 0)
     {
@@ -572,11 +566,10 @@ uniquify_destroy (void *aux)
 */
 struct casereader *
 casereader_create_distinct (struct casereader *input,
-					       const struct variable *key,
-					       const struct variable *weight)
+                                               const struct variable *key,
+                                               const struct variable *weight)
 {
   struct casereader *u ;
-  struct casereader *ud ;
   struct caseproto *output_proto = caseproto_ref (casereader_get_proto (input));
 
   struct consolidator *cdr = xmalloc (sizeof (*cdr));
@@ -593,14 +586,11 @@ casereader_create_distinct (struct casereader *input,
   cdr->proto = output_proto;
 
   u = casereader_create_filter_func (input, uniquify,
-				     NULL, cdr, NULL);
+                                     NULL, cdr, NULL);
 
-  ud = casereader_create_translator (u,
-				     output_proto,
-				     consolodate_weight,
-				     uniquify_destroy,
-				     cdr);
-
-  return ud;
+  static const struct casereader_translator_class class = {
+    consolodate_weight, uniquify_destroy,
+  };
+  return casereader_create_translator (u, output_proto, &class, cdr);
 }
 
