@@ -51,8 +51,8 @@ static bool axis_allocate (struct axis *, unsigned long int request,
                            unsigned long int *start,
                            unsigned long int *width);
 static void axis_make_available (struct axis *,
-				 unsigned long int start,
-				 unsigned long int width);
+                                 unsigned long int start,
+                                 unsigned long int width);
 static unsigned long int axis_extend (struct axis *, unsigned long int width);
 
 static unsigned long int axis_map (const struct axis *, unsigned long log_pos);
@@ -190,6 +190,7 @@ caseproto_to_n_bytes (const struct caseproto *proto)
   for (i = 0; i < caseproto_get_n_widths (proto); i++)
     {
       int width = caseproto_get_width (proto, i);
+      assert (width >= 0);
       if (width >= 0)
         n_bytes += width_to_n_bytes (width);
     }
@@ -236,6 +237,7 @@ datasheet_create (struct casereader *reader)
           int width = caseproto_get_width (ds->proto, i);
           column->source = ds->sources[0];
           column->width = width;
+          assert (width >= 0);
           if (width >= 0)
             {
               column->value_ofs = i;
@@ -416,11 +418,12 @@ datasheet_move_columns (struct datasheet *ds,
                         size_t old_start, size_t new_start,
                         size_t n)
 {
-  assert (old_start + n <= ds->n_columns);
   assert (new_start + n <= ds->n_columns);
-
-  move_range (ds->columns, ds->n_columns, sizeof *ds->columns,
-              old_start, new_start, n);
+  if  (old_start + n <= ds->n_columns)
+    {
+      move_range (ds->columns, ds->n_columns, sizeof *ds->columns,
+                  old_start, new_start, n);
+    }
 
   caseproto_unref (ds->proto);
   ds->proto = NULL;
@@ -473,6 +476,8 @@ datasheet_resize_column (struct datasheet *ds, size_t column, int new_width,
   col = &ds->columns[column];
   old_col = *col;
   old_width = old_col.width;
+  assert (old_width >= 0);
+  assert (new_width >= 0);
 
   if (new_width == -1)
     {
@@ -522,7 +527,7 @@ datasheet_resize_column (struct datasheet *ds, size_t column, int new_width,
       value_destroy (&src, old_width);
       value_destroy (&dst, new_width);
       if (lrow < n_rows)
-	return false;
+        return false;
 
       release_source (ds, old_col.source);
     }
@@ -756,6 +761,7 @@ allocate_column (struct datasheet *ds, int width, struct column *column)
 
   column->value_ofs = -1;
   column->width = width;
+  assert (width >= 0);
   if (width >= 0)
     {
       int n_bytes;
@@ -864,7 +870,7 @@ rw_case (struct datasheet *ds, enum rw_op op,
 struct axis
 {
   struct tower log_to_phy;     /* Map from logical to physical ordinates;
-				  contains "struct axis_group"s. */
+                                  contains "struct axis_group"s. */
   struct range_set *available; /* Set of unused, available ordinates. */
   unsigned long int phy_size;  /* Current physical length of axis. */
 };
@@ -1402,6 +1408,7 @@ copy_case_into_source (struct source *source, struct ccase *c, casenumber row)
   for (i = 0; i < n_widths; i++)
     {
       int width = caseproto_get_width (proto, i);
+      assert (width >= 0);
       if (width >= 0)
         {
           int n_bytes = width_to_n_bytes (width);
