@@ -64,9 +64,9 @@ struct variable *dict_clone_var_as (struct dictionary *,
 struct variable *dict_clone_var_as_assert (struct dictionary *,
                                            const struct variable *,
                                            const char *);
-
-struct variable *dict_clone_var_in_place_assert (struct dictionary *,
-                                                 const struct variable *);
+struct variable *dict_create_var_with_unique_name (struct dictionary *,
+                                                   const char *hint,
+                                                   int width);
 
 /* Deleting variables. */
 void dict_delete_var (struct dictionary *, struct variable *);
@@ -89,18 +89,19 @@ void dict_rename_var (struct dictionary *, struct variable *, const char *);
 bool dict_rename_vars (struct dictionary *,
                        struct variable **, char **new_names,
                        size_t count, char **err_name);
-char *dict_make_unique_var_name (const struct dictionary *, const char *hint,
-                                 unsigned long int *num_start);
+char *dict_make_unique_var_name (const struct dictionary *, const char *hint);
 
 bool dict_get_names_must_be_ids (const struct dictionary *);
 void dict_set_names_must_be_ids (struct dictionary *, bool);
 
 /* Weight variable. */
 double dict_get_case_weight (const struct dictionary *,
-			     const struct ccase *, bool *);
+                             const struct ccase *, bool *);
+double dict_get_rounded_case_weight (const struct dictionary *,
+                                     const struct ccase *, bool *);
 struct variable *dict_get_weight (const struct dictionary *);
 void dict_set_weight (struct dictionary *, struct variable *);
-const struct fmt_spec *dict_get_weight_format (const struct dictionary *);
+struct fmt_spec dict_get_weight_format (const struct dictionary *);
 
 /* Filter variable. */
 struct variable *dict_get_filter (const struct dictionary *);
@@ -112,22 +113,30 @@ void dict_set_case_limit (struct dictionary *, casenumber);
 
 /* Size of cases for this dictionary. */
 const struct caseproto *dict_get_proto (const struct dictionary *);
-int dict_get_next_value_idx (const struct dictionary *);
-size_t dict_get_case_size (const struct dictionary *);
 
 /* Making this dictionary's cases smaller (if some variables were
    deleted). */
 size_t dict_count_values (const struct dictionary *,
                           unsigned int exclude_classes);
 void dict_compact_values (struct dictionary *);
-struct caseproto *dict_get_compacted_proto (const struct dictionary *,
-                                            unsigned int exclude_classes);
 
-/* SPLIT FILE variables. */
+/* SPLIT FILE variables.
+
+   SPLIT_NONE is used if and only if there are no split file variables. */
+enum split_type
+  {
+    SPLIT_NONE,                 /* No split file variables. */
+    SPLIT_SEPARATE,             /* Produce separate output for each split. */
+    SPLIT_LAYERED,              /* Output splits in same table.  */
+  };
+#define MAX_SPLITS 8
 const struct variable *const *dict_get_split_vars (const struct dictionary *);
 size_t dict_get_n_splits (const struct dictionary *);
+enum split_type dict_get_split_type (const struct dictionary *);
 void dict_set_split_vars (struct dictionary *,
-                          struct variable *const *, size_t n);
+                          struct variable *const *, size_t n,
+                          enum split_type);
+void dict_clear_split_vars (struct dictionary *);
 
 /* File label. */
 const char *dict_get_label (const struct dictionary *);
@@ -167,6 +176,16 @@ bool dict_add_mrset (struct dictionary *, struct mrset *);
 bool dict_delete_mrset (struct dictionary *, const char *name);
 void dict_clear_mrsets (struct dictionary *);
 
+/* Variable sets. */
+const struct varset *dict_get_varset (const struct dictionary *, size_t idx);
+size_t dict_get_n_varsets (const struct dictionary *);
+const struct varset *dict_lookup_varset (const struct dictionary *,
+                                         const char *name);
+
+bool dict_add_varset (struct dictionary *, struct varset *);
+bool dict_delete_varset (struct dictionary *, const char *name);
+void dict_clear_varsets (struct dictionary *);
+
 /* Attributes. */
 struct attrset *dict_get_attributes (const struct dictionary *);
 void dict_set_attributes (struct dictionary *, const struct attrset *);
@@ -175,19 +194,18 @@ bool dict_has_attributes (const struct dictionary *);
 /* Data encoding. */
 const char *dict_get_encoding (const struct dictionary *d);
 
+char *dict_id_is_valid__ (const struct dictionary *, const char *id,
+                          enum dict_class)
+  WARN_UNUSED_RESULT;
 bool dict_id_is_valid (const struct dictionary *, const char *id,
-                       bool issue_error);
-
-/* Internal variables. */
-struct variable *dict_create_internal_var (int case_idx, int width);
-void dict_destroy_internal_var (struct variable *);
+                       enum dict_class);
 
 /* Functions to be called upon dictionary changes. */
 struct dict_callbacks
  {
   void (*var_added) (struct dictionary *, int, void *);
-  void (*var_deleted) (struct dictionary *, const struct variable *,
-                       int dict_index, int case_index, void *);
+  void (*vars_deleted) (struct dictionary *, int dict_index, unsigned int n, void *);
+  void (*var_moved) (struct dictionary *, int new_dict_index, int old_dict_index, void *);
   void (*var_changed) (struct dictionary *, int, unsigned int, const struct variable *, void *);
   void (*weight_changed) (struct dictionary *, int, void *);
   void (*filter_changed) (struct dictionary *, int, void *);
@@ -195,12 +213,12 @@ struct dict_callbacks
  };
 
 void dict_set_callbacks (struct dictionary *, const struct dict_callbacks *,
-			 void *);
+                         void *);
 void dict_copy_callbacks (struct dictionary *, const struct dictionary *);
 
 void dict_set_change_callback (struct dictionary *d,
-			       void (*changed) (struct dictionary *, void*),
-			       void *data);
+                               void (*changed) (struct dictionary *, void*),
+                               void *data);
 
 
 /* Debug use only. */
