@@ -21,25 +21,27 @@
 #include <stdio.h>
 #include <sys/types.h>
 
+struct file_handle;
+
 /* Prepares to atomically replace a (potentially) existing file
-   by a new file, by creating a temporary file with the given
-   PERMISSIONS bits in the same directory as *FILE_NAME.
+   by a new file., by creating a temporary file with the given
+   PERMISSIONS bits.
 
    Special files are an exception: they are not atomically
    replaced but simply opened for writing.
 
-   If successful, stores the temporary file's name in *TMP_NAME
-   and a stream for it opened according to MODE (which should be
+   If successful, stores a stream for it opened according to MODE (which should be
    "w" or "wb") in *FP.  Returns a ticket that can be used to
    commit or abort the file replacement.  If neither action has
    yet been taken, program termination via signal will cause
-   *TMP_FILE to be unlinked.
+   all resources to be released.  The return value must not be
+   explicitly freed.
 
-   The caller is responsible for closing *FP, but *TMP_NAME is
-   owned by the callee. */
-struct replace_file *replace_file_start (const char *file_name,
+   The caller is responsible for closing *FP */
+
+struct replace_file *replace_file_start (const struct file_handle *fh,
                                          const char *mode, mode_t permissions,
-                                         FILE **fp, char **tmp_name);
+                                         FILE **fp);
 
 /* Commits or aborts the replacement of a (potentially) existing
    file by a new file, using the ticket returned by
