@@ -50,11 +50,6 @@
 #include "gettext.h"
 #define _(msgid) gettext (msgid)
 
-/* Setting this to false can help with debugging and development.
-   Don't forget to set it back to true, or users will complain that
-   all but the smallest spreadsheets display VERY slowly.  */
-static const bool use_cache = true;
-
 static void ods_file_casereader_destroy (struct casereader *, void *);
 static struct ccase *ods_file_casereader_read (struct casereader *, void *);
 
@@ -73,7 +68,6 @@ enum reader_state
     STATE_TABLE,           /* Found the sheet that we actually want */
     STATE_ROW,             /* Found the start of the cell array */
     STATE_CELL,            /* Found a cell */
-    STATE_CELL_CONTENT     /* Found a the text within a cell */
   };
 
 struct state_data
@@ -186,7 +180,7 @@ reading_target_sheet (const struct ods_reader *r, const struct state_data *sd)
   if (r->target_sheet_name != NULL)
     {
       if (0 == xmlStrcmp (r->target_sheet_name, sd->current_sheet_name))
-	return true;
+        return true;
     }
 
   if (r->target_sheet_index == sd->current_sheet + 1)
@@ -196,7 +190,7 @@ reading_target_sheet (const struct ods_reader *r, const struct state_data *sd)
 }
 
 
-static void process_node (struct ods_reader *or, struct state_data *r);
+static bool process_node (struct ods_reader *or, struct state_data *r);
 
 
 /* Initialise SD using R */
@@ -231,15 +225,10 @@ ods_get_sheet_name (struct spreadsheet *s, int n)
   struct state_data sd;
   state_data_init (r, &sd);
 
-  while ((r->n_allocated_sheets <= n)
-	 || sd.state != STATE_SPREADSHEET)
-    {
-      int ret = xmlTextReaderRead (sd.xtr);
-      if (ret != 1)
-	break;
-
-      process_node (r, &sd);
-    }
+  while ((r->n_allocated_sheets <= n
+          || sd.state != STATE_SPREADSHEET)
+         && process_node (r, &sd))
+    continue;
   state_data_destroy (&sd);
 
   return r->spreadsheet.sheets[n].name;
@@ -252,23 +241,18 @@ ods_get_sheet_range (struct spreadsheet *s, int n)
   struct state_data sd;
   state_data_init (r, &sd);
 
-  while ((r->n_allocated_sheets <= n)
-	  || (r->spreadsheet.sheets[n].last_row == -1)
-	 || sd.state != STATE_SPREADSHEET)
-    {
-      int ret = xmlTextReaderRead (sd.xtr);
-      if (ret != 1)
-	break;
-
-      process_node (r, &sd);
-    }
+  while ((r->n_allocated_sheets <= n
+          || r->spreadsheet.sheets[n].last_row == -1
+          || sd.state != STATE_SPREADSHEET)
+         && process_node (r, &sd))
+    continue;
   state_data_destroy (&sd);
 
   return create_cell_range (
-			  r->spreadsheet.sheets[n].first_col,
-			  r->spreadsheet.sheets[n].first_row,
-			  r->spreadsheet.sheets[n].last_col,
-			  r->spreadsheet.sheets[n].last_row);
+                          r->spreadsheet.sheets[n].first_col,
+                          r->spreadsheet.sheets[n].first_row,
+                          r->spreadsheet.sheets[n].last_col,
+                          r->spreadsheet.sheets[n].last_row);
 }
 
 static unsigned int
@@ -283,12 +267,8 @@ ods_get_sheet_n_rows (struct spreadsheet *s, int n)
     }
 
   state_data_init (r, &sd);
-
-  while (1 == xmlTextReaderRead (sd.xtr))
-    {
-      process_node (r, &sd);
-    }
-
+  while (process_node (r, &sd))
+    continue;
   state_data_destroy (&sd);
 
   return r->spreadsheet.sheets[n].last_row + 1;
@@ -304,126 +284,79 @@ ods_get_sheet_n_columns (struct spreadsheet *s, int n)
     return r->spreadsheet.sheets[n].last_col + 1;
 
   state_data_init (r, &sd);
-
-  while (1 == xmlTextReaderRead (sd.xtr))
-    {
-      process_node (r, &sd);
-    }
-
+  while (process_node (r, &sd))
+    continue;
   state_data_destroy (&sd);
 
   return r->spreadsheet.sheets[n].last_col + 1;
 }
 
+static unsigned int
+cell_hash (int n, int row, int column)
+{
+  return hash_int (column, hash_int (row, hash_int (n, 0)));
+}
+
+static struct cache_datum *
+cache_lookup (struct ods_reader *r, int n, int row, int column)
+{
+  unsigned int hash = cell_hash (n, row, column);
+
+  struct cache_datum *d;
+  HMAP_FOR_EACH_WITH_HASH (d, struct cache_datum, node, hash, &r->cache)
+    if (d->row == row && d->col == column && d->sheet == n)
+      return d;
+  return NULL;
+}
+
+static void
+populate_cache (struct ods_reader *r)
+{
+  struct state_data sd;
+
+  state_data_init (r, &sd);
+
+  while (process_node (r, &sd))
+    {
+      if (sd.state == STATE_CELL)
+        {
+          /* When cell contents are encountered, copy and save it, discarding
+             any older content.  */
+          char *cell_content = CHAR_CAST (char *, xmlNodeGetContent (
+                                            xmlTextReaderExpand (sd.xtr)));
+
+          for (int c = sd.col - sd.col_span; c < sd.col; ++c)
+            {
+              if (cache_lookup (r, sd.current_sheet, sd.row, c))
+                continue;
+
+              struct cache_datum *cell_data = xmalloc (sizeof *cell_data);
+              *cell_data = (struct cache_datum) {
+                .row = sd.row - 1,
+                .col = c,
+                .sheet = sd.current_sheet,
+                .value = xstrdup_if_nonnull (cell_content),
+              };
+              hmap_insert (&r->cache, &cell_data->node,
+                           cell_hash (sd.current_sheet, sd.row - 1, c));
+            }
+          free (cell_content);
+        }
+    }
+
+  state_data_destroy (&sd);
+}
+
 static char *
 ods_get_sheet_cell (struct spreadsheet *s, int n, int row, int column)
 {
   struct ods_reader *r = (struct ods_reader *) s;
-  struct state_data sd;
 
-  /* See if this cell is in the cache.  If it is, then use it.  */
-  if (use_cache)
-  {
-    struct cache_datum *lookup = NULL;
-    unsigned int hash = hash_int (n, 0);
-    hash = hash_int (row, hash);
-    hash = hash_int (column, hash);
+  if (hmap_is_empty (&r->cache))
+    populate_cache (r);
 
-    HMAP_FOR_EACH_WITH_HASH (lookup, struct cache_datum, node, hash,
-                             &r->cache)
-      {
-        if (lookup->row == row && lookup->col == column
-            && lookup->sheet == n)
-          {
-            break;
-          }
-      }
-    if (lookup)
-      {
-        return lookup->value ? strdup (lookup->value) : NULL;
-      }
-  }
-
-  state_data_init (r, &sd);
-
-  char *cell_content = NULL;
-
-  int prev_col = 0;
-  int prev_row = 0;
-  while (1 == xmlTextReaderRead (sd.xtr))
-    {
-      process_node (r, &sd);
-      if (sd.row > prev_row)
-	prev_col = 0;
-
-      if (sd.state == STATE_CELL_CONTENT
-          && sd.current_sheet == n
-          && sd.node_type == XML_READER_TYPE_TEXT)
-        {
-          /*  When cell contents are encountered, copy and save it, discarding
-              any older content.  */
-          free (cell_content);
-          cell_content = CHAR_CAST (char *, xmlTextReaderValue (sd.xtr));
-        }
-      if (sd.state == STATE_ROW
-               && sd.current_sheet == n
-               && sd.node_type == XML_READER_TYPE_ELEMENT)
-        {
-          /* At the start of a row, free the cell contents and set it to NULL.  */
-          free (cell_content);
-          cell_content = NULL;
-        }
-      if (sd.state == STATE_ROW
-          && sd.current_sheet == n
-          &&
-               (sd.node_type == XML_READER_TYPE_END_ELEMENT
-                ||
-                xmlTextReaderIsEmptyElement (sd.xtr)))
-        {
-          if (use_cache)
-            {
-	      for (int c = prev_col; c < sd.col; ++c)
-		{
-		  /* See if this cell has already been cached ... */
-		  unsigned int hash = hash_int (sd.current_sheet, 0);
-		  hash = hash_int (sd.row - 1, hash);
-		  hash = hash_int (c, hash);
-		  struct cache_datum *probe = NULL;
-		  struct cache_datum *next;
-		  HMAP_FOR_EACH_WITH_HASH_SAFE (probe, next, struct cache_datum, node, hash,
-						&r->cache)
-		    {
-		      if (probe->row == sd.row - 1 && probe->col == c
-			  && probe->sheet == sd.current_sheet)
-			break;
-		      probe = NULL;
-		    }
-		  /* If not, then cache it.  */
-		  if (!probe)
-		    {
-		      struct cache_datum *cell_data = XMALLOC (struct cache_datum);
-		      cell_data->row = sd.row - 1;
-		      cell_data->col = c;
-		      cell_data->sheet = sd.current_sheet;
-		      cell_data->value = cell_content ? strdup (cell_content) : NULL;
-
-		      hmap_insert (&r->cache, &cell_data->node, hash);
-		    }
-		}
-            }
-
-          if (sd.row == row + 1 && sd.col >= column + 1)
-	    {
-	      break;
-	    }
-
-	  prev_col = sd.col;
-	  prev_row = sd.row;
-        }
-    }
-
-  state_data_destroy (&sd);
-  return cell_content;
+  const struct cache_datum *datum = cache_lookup (r, n, row, column);
+  return datum ? xstrdup_if_nonnull (datum->value) : NULL;
 }
 
 static void
@@ -452,9 +385,15 @@ ods_file_casereader_destroy (struct casereader *reader UNUSED, void *r_)
   spreadsheet_unref (&r->spreadsheet);
 }
 
-static void
+static bool
 process_node (struct ods_reader *or, struct state_data *r)
 {
+  int ret = (r->state == STATE_CELL
+             ? xmlTextReaderNext (r->xtr)
+             : xmlTextReaderRead (r->xtr));
+  if (ret != 1)
+    return false;
+
   xmlChar *name = xmlTextReaderName (r->xtr);
   if (name == NULL)
     name = xmlStrdup (_xml ("--"));
@@ -466,134 +405,118 @@ process_node (struct ods_reader *or, struct state_data *r)
     {
     case STATE_INIT:
       if (0 == xmlStrcasecmp (name, _xml("office:spreadsheet")) &&
-	  XML_READER_TYPE_ELEMENT  == r->node_type)
-	{
-	  r->state = STATE_SPREADSHEET;
-	  r->current_sheet = -1;
-	  r->current_sheet_name = NULL;
-	}
+          XML_READER_TYPE_ELEMENT  == r->node_type)
+        {
+          r->state = STATE_SPREADSHEET;
+          r->current_sheet = -1;
+          r->current_sheet_name = NULL;
+        }
       break;
     case STATE_SPREADSHEET:
       if (0 == xmlStrcasecmp (name, _xml("table:table"))
-	  &&
-	  (XML_READER_TYPE_ELEMENT == r->node_type))
-	{
-	  xmlFree (r->current_sheet_name);
-	  r->current_sheet_name = xmlTextReaderGetAttribute (r->xtr, _xml ("table:name"));
+          &&
+          (XML_READER_TYPE_ELEMENT == r->node_type))
+        {
+          xmlFree (r->current_sheet_name);
+          r->current_sheet_name = xmlTextReaderGetAttribute (r->xtr, _xml ("table:name"));
 
-	  ++r->current_sheet;
+          ++r->current_sheet;
 
-	  if (r->current_sheet >= or->n_allocated_sheets)
-	    {
-	      assert (r->current_sheet == or->n_allocated_sheets);
-	      or->spreadsheet.sheets = xrealloc (or->spreadsheet.sheets, sizeof (*or->spreadsheet.sheets) * ++or->n_allocated_sheets);
-	      or->spreadsheet.sheets[or->n_allocated_sheets - 1].first_col = -1;
-	      or->spreadsheet.sheets[or->n_allocated_sheets - 1].last_col = -1;
-	      or->spreadsheet.sheets[or->n_allocated_sheets - 1].first_row = -1;
-	      or->spreadsheet.sheets[or->n_allocated_sheets - 1].last_row = -1;
-	      or->spreadsheet.sheets[or->n_allocated_sheets - 1].name = CHAR_CAST (char *, xmlStrdup (r->current_sheet_name));
-	    }
-	  if (or->n_allocated_sheets > or->n_sheets)
-	    or->n_sheets = or->n_allocated_sheets;
+          if (r->current_sheet >= or->n_allocated_sheets)
+            {
+              assert (r->current_sheet == or->n_allocated_sheets);
+              or->spreadsheet.sheets = xrealloc (or->spreadsheet.sheets, sizeof (*or->spreadsheet.sheets) * ++or->n_allocated_sheets);
+              or->spreadsheet.sheets[or->n_allocated_sheets - 1].first_col = -1;
+              or->spreadsheet.sheets[or->n_allocated_sheets - 1].last_col = -1;
+              or->spreadsheet.sheets[or->n_allocated_sheets - 1].first_row = -1;
+              or->spreadsheet.sheets[or->n_allocated_sheets - 1].last_row = -1;
+              or->spreadsheet.sheets[or->n_allocated_sheets - 1].name = CHAR_CAST (char *, xmlStrdup (r->current_sheet_name));
+            }
+          if (or->n_allocated_sheets > or->n_sheets)
+            or->n_sheets = or->n_allocated_sheets;
 
-	  r->col = 0;
-	  r->row = 0;
+          r->col = 0;
+          r->row = 0;
 
-	  r->state = STATE_TABLE;
-	}
+          r->state = STATE_TABLE;
+        }
       else if (0 == xmlStrcasecmp (name, _xml("office:spreadsheet")) &&
-	       XML_READER_TYPE_ELEMENT  == r->node_type)
-	{
-	  r->state = STATE_INIT;
-	}
+               XML_READER_TYPE_ELEMENT  == r->node_type)
+        {
+          r->state = STATE_INIT;
+        }
       break;
     case STATE_TABLE:
       if (0 == xmlStrcasecmp (name, _xml("table:table-row")) &&
-	  (XML_READER_TYPE_ELEMENT  == r->node_type))
-	{
-	  xmlChar *value =
-	    xmlTextReaderGetAttribute (r->xtr,
-				       _xml ("table:number-rows-repeated"));
+          (XML_READER_TYPE_ELEMENT  == r->node_type))
+        {
+          xmlChar *value =
+            xmlTextReaderGetAttribute (r->xtr,
+                                       _xml ("table:number-rows-repeated"));
 
-	  int row_span = value ? _xmlchar_to_int (value) : 1;
+          int row_span = value ? _xmlchar_to_int (value) : 1;
 
-	  r->row += row_span;
-	  r->col = 0;
+          r->row += row_span;
+          r->col = 0;
 
-	  if (! xmlTextReaderIsEmptyElement (r->xtr))
-	    r->state = STATE_ROW;
+          if (! xmlTextReaderIsEmptyElement (r->xtr))
+            r->state = STATE_ROW;
 
-	  xmlFree (value);
-	}
+          xmlFree (value);
+        }
       else if (0 == xmlStrcasecmp (name, _xml("table:table")) &&
-	       (XML_READER_TYPE_END_ELEMENT  == r->node_type))
-	{
-	  r->state = STATE_SPREADSHEET;
-	}
+               (XML_READER_TYPE_END_ELEMENT  == r->node_type))
+        {
+          r->state = STATE_SPREADSHEET;
+        }
       break;
+
+    case STATE_CELL:
+      r->state = STATE_ROW;
+      /* Fall through. */
     case STATE_ROW:
       if ((0 == xmlStrcasecmp (name, _xml ("table:table-cell")))
-	   &&
-	   (XML_READER_TYPE_ELEMENT  == r->node_type))
-	{
-	  xmlChar *value =
-	    xmlTextReaderGetAttribute (r->xtr,
-				       _xml ("table:number-columns-repeated"));
+           &&
+           (XML_READER_TYPE_ELEMENT  == r->node_type))
+        {
+          xmlChar *value =
+            xmlTextReaderGetAttribute (r->xtr,
+                                       _xml ("table:number-columns-repeated"));
 
-	  r->col_span = value ? _xmlchar_to_int (value) : 1;
-	  r->col += r->col_span;
+          r->col_span = value ? _xmlchar_to_int (value) : 1;
+          r->col += r->col_span;
+          xmlFree (value);
 
-	  if (! xmlTextReaderIsEmptyElement (r->xtr))
-	    r->state = STATE_CELL;
+          if (! xmlTextReaderIsEmptyElement (r->xtr))
+            {
+              assert (r->current_sheet >= 0);
+              assert (r->current_sheet < or->n_allocated_sheets);
 
-	  xmlFree (value);
-	}
+              if (or->spreadsheet.sheets[r->current_sheet].first_row == -1)
+                or->spreadsheet.sheets[r->current_sheet].first_row = r->row - 1;
+
+              if (
+                (or->spreadsheet.sheets[r->current_sheet].first_col == -1)
+                ||
+                (or->spreadsheet.sheets[r->current_sheet].first_col >= r->col - 1)
+                  )
+                or->spreadsheet.sheets[r->current_sheet].first_col = r->col - 1;
+
+              if (or->spreadsheet.sheets[r->current_sheet].last_row < r->row - 1)
+                or->spreadsheet.sheets[r->current_sheet].last_row = r->row - 1;
+
+              if (or->spreadsheet.sheets[r->current_sheet].last_col < r->col - 1)
+                or->spreadsheet.sheets[r->current_sheet].last_col = r->col - 1;
+
+              r->state = STATE_CELL;
+            }
+        }
       else if ((0 == xmlStrcasecmp (name, _xml ("table:table-row")))
-		&&
-		(XML_READER_TYPE_END_ELEMENT  == r->node_type))
-	{
-	  r->state = STATE_TABLE;
-	}
-      break;
-    case STATE_CELL:
-      if ((0 == xmlStrcasecmp (name, _xml("text:p")))
-	    &&
-	   (XML_READER_TYPE_ELEMENT  == r->node_type))
-	{
-	  if (! xmlTextReaderIsEmptyElement (r->xtr))
-	    r->state = STATE_CELL_CONTENT;
-	}
-      else if
-	((0 == xmlStrcasecmp (name, _xml("table:table-cell")))
-	  &&
-	  (XML_READER_TYPE_END_ELEMENT  == r->node_type)
-	)
-	{
-	  r->state = STATE_ROW;
-	}
-      break;
-    case STATE_CELL_CONTENT:
-      assert (r->current_sheet >= 0);
-      assert (r->current_sheet < or->n_allocated_sheets);
-
-      if (or->spreadsheet.sheets[r->current_sheet].first_row == -1)
-	or->spreadsheet.sheets[r->current_sheet].first_row = r->row - 1;
-
-      if (
-	  (or->spreadsheet.sheets[r->current_sheet].first_col == -1)
-	  ||
-	  (or->spreadsheet.sheets[r->current_sheet].first_col >= r->col - 1)
-	)
-	or->spreadsheet.sheets[r->current_sheet].first_col = r->col - 1;
-
-      if (or->spreadsheet.sheets[r->current_sheet].last_row < r->row - 1)
-	or->spreadsheet.sheets[r->current_sheet].last_row = r->row - 1;
-
-      if (or->spreadsheet.sheets[r->current_sheet].last_col < r->col - 1)
-	or->spreadsheet.sheets[r->current_sheet].last_col = r->col - 1;
-
-      if (XML_READER_TYPE_END_ELEMENT  == r->node_type)
-	r->state = STATE_CELL;
+                &&
+                (XML_READER_TYPE_END_ELEMENT  == r->node_type))
+        {
+          r->state = STATE_TABLE;
+        }
       break;
     default:
       NOT_REACHED ();
@@ -601,6 +524,8 @@ process_node (struct ods_reader *or, struct state_data *r)
     };
 
   xmlFree (name);
+
+  return true;
 }
 
 /*
@@ -636,10 +561,10 @@ xmv_to_width (const struct xml_value *xmv, int fallback)
 
   if (xmv->value)
     width = ROUND_UP (xmlStrlen (xmv->value),
-		      SPREADSHEET_DEFAULT_WIDTH);
+                      SPREADSHEET_DEFAULT_WIDTH);
   else if (xmv->text)
     width = ROUND_UP (xmlStrlen (xmv->text),
-		      SPREADSHEET_DEFAULT_WIDTH);
+                      SPREADSHEET_DEFAULT_WIDTH);
 
   return width;
 }
@@ -649,7 +574,7 @@ xmv_to_width (const struct xml_value *xmv, int fallback)
  */
 static void
 convert_xml_to_value (struct ccase *c, const struct variable *var,
-		      const struct xml_value *xmv, int col, int row)
+                      const struct xml_value *xmv, int col, int row)
 {
   union value *v = case_data_rw (c, var);
 
@@ -661,35 +586,35 @@ convert_xml_to_value (struct ccase *c, const struct variable *var,
     value_copy_str_rpad (v, var_get_width (var), xmv->text, ' ');
   else
     {
-      const struct fmt_spec *fmt = var_get_write_format (var);
-      enum fmt_category fc  = fmt_get_category (fmt->type);
+      const struct fmt_spec fmt = var_get_write_format (var);
+      enum fmt_category fc  = fmt_get_category (fmt.type);
 
       assert (fc != FMT_CAT_STRING);
 
       if (0 == xmlStrcmp (xmv->type, _xml("float")))
-	{
-	  v->f = c_strtod (CHAR_CAST (const char *, xmv->value), NULL);
-	}
+        {
+          v->f = c_strtod (CHAR_CAST (const char *, xmv->value), NULL);
+        }
       else
-	{
-	  const char *text = xmv->value ?
-	    CHAR_CAST (const char *, xmv->value) : CHAR_CAST (const char *, xmv->text);
+        {
+          const char *text = xmv->value ?
+            CHAR_CAST (const char *, xmv->value) : CHAR_CAST (const char *, xmv->text);
 
-	  char *m = data_in (ss_cstr (text), "UTF-8", fmt->type,
+          char *m = data_in (ss_cstr (text), "UTF-8", fmt.type,
                              settings_get_fmt_settings (), v,
                              var_get_width (var), "UTF-8");
 
-	  if (m)
-	    {
-	      char buf [FMT_STRING_LEN_MAX + 1];
-	      char *cell = create_cell_ref (col, row);
+          if (m)
+            {
+              char buf [FMT_STRING_LEN_MAX + 1];
+              char *cell = create_cell_ref (col, row);
 
-	      msg (MW, _("Cannot convert the value in the spreadsheet cell %s to format (%s): %s"),
-		   cell, fmt_to_string (fmt, buf), m);
-	      free (cell);
-	    }
-	  free (m);
-	}
+              msg (MW, _("Cannot convert the value in the spreadsheet cell %s to format (%s): %s"),
+                   cell, fmt_to_string (fmt, buf), m);
+              free (cell);
+            }
+          free (m);
+        }
     }
 }
 
@@ -712,20 +637,20 @@ get_sheet_count (struct zip_reader *zreader)
     {
       xmlChar *name = xmlTextReaderName (mxtr);
       if (0 == xmlStrcmp (name, _xml("meta:document-statistic")))
-	{
-	  xmlChar *attr = xmlTextReaderGetAttribute (mxtr, _xml ("meta:table-count"));
+        {
+          xmlChar *attr = xmlTextReaderGetAttribute (mxtr, _xml ("meta:table-count"));
 
-	  if (attr != NULL)
-	    {
-	      int s = _xmlchar_to_int (attr);
-	      xmlFreeTextReader (mxtr);
+          if (attr != NULL)
+            {
+              int s = _xmlchar_to_int (attr);
+              xmlFreeTextReader (mxtr);
               zip_member_finish (meta);
-	      xmlFree (name);
-	      xmlFree (attr);
-	      return s;
-	    }
-	  xmlFree (attr);
-	}
+              xmlFree (name);
+              xmlFree (attr);
+              return s;
+            }
+          xmlFree (attr);
+        }
       xmlFree (name);
     }
 
@@ -750,8 +675,8 @@ ods_get_sheet_n_sheets (struct spreadsheet *s)
 
 static void
 ods_error_handler (void *ctx, const char *mesg,
-		   xmlParserSeverities sev UNUSED,
-		   xmlTextReaderLocatorPtr loc)
+                   xmlParserSeverities sev UNUSED,
+                   xmlTextReaderLocatorPtr loc)
 {
   struct ods_reader *r = ctx;
 
@@ -767,11 +692,9 @@ static bool init_reader (struct ods_reader *r, bool report_errors, struct state_
 
 static struct casereader *
 ods_make_reader (struct spreadsheet *spreadsheet,
-		 const struct spreadsheet_read_options *opts)
+                 const struct spreadsheet_read_options *opts)
 {
-  intf ret = 0;
   xmlChar *type = NULL;
-  unsigned long int vstart = 0;
   casenumber n_cases = CASENUMBER_MAX;
   int i;
   struct var_spec *var_spec = NULL;
@@ -793,13 +716,13 @@ ods_make_reader (struct spreadsheet *spreadsheet,
   if (opts->cell_range)
     {
       if (! convert_cell_ref (opts->cell_range,
-			       &r->spreadsheet.start_col, &r->spreadsheet.start_row,
-			       &r->spreadsheet.stop_col, &r->spreadsheet.stop_row))
-	{
-	  msg (SE, _("Invalid cell range `%s'"),
-	       opts->cell_range);
-	  goto error;
-	}
+                               &r->spreadsheet.start_col, &r->spreadsheet.start_row,
+                               &r->spreadsheet.stop_col, &r->spreadsheet.stop_row))
+        {
+          msg (SE, _("Invalid cell range `%s'"),
+               opts->cell_range);
+          goto error;
+        }
     }
   else
     {
@@ -813,121 +736,109 @@ ods_make_reader (struct spreadsheet *spreadsheet,
   r->target_sheet_index = opts->sheet_index;
 
   /* Advance to the start of the cells for the target sheet */
-  while (! reading_target_sheet (r, &r->rsd)
-	  || r->rsd.state != STATE_ROW || r->rsd.row <= r->spreadsheet.start_row)
-    {
-      if (1 != (ret = xmlTextReaderRead (r->rsd.xtr)))
-	   break;
-
-      process_node (r, &r->rsd);
-    }
-
-  if (ret < 1)
-    {
-      msg (MW, _("Selected sheet or range of spreadsheet `%s' is empty."),
-           spreadsheet->file_name);
-      goto error;
-    }
+  while (!reading_target_sheet (r, &r->rsd)
+         || r->rsd.state != STATE_ROW
+         || r->rsd.row <= r->spreadsheet.start_row)
+    if (!process_node (r, &r->rsd))
+      {
+        msg (MW, _("Selected sheet or range of spreadsheet `%s' is empty."),
+             spreadsheet->file_name);
+        goto error;
+      }
 
   if (opts->read_names)
     {
-      while (1 == xmlTextReaderRead (r->rsd.xtr))
-	{
-	  process_node (r, &r->rsd);
+      while (process_node (r, &r->rsd))
+        {
+          /* If the row is finished then stop for now */
+          if (r->rsd.state == STATE_TABLE && r->rsd.row > r->spreadsheet.start_row)
+            break;
 
-	  /* If the row is finished then stop for now */
-	  if (r->rsd.state == STATE_TABLE && r->rsd.row > r->spreadsheet.start_row)
-	    break;
+          int idx = r->rsd.col - r->spreadsheet.start_col - 1;
 
-	  int idx = r->rsd.col - r->spreadsheet.start_col - 1;
+          if (idx < 0)
+            continue;
 
-	  if (idx < 0)
-	    continue;
+          if (r->spreadsheet.stop_col != -1 && idx > r->spreadsheet.stop_col - r->spreadsheet.start_col)
+            continue;
 
-	  if (r->spreadsheet.stop_col != -1 && idx > r->spreadsheet.stop_col - r->spreadsheet.start_col)
-	    continue;
+          if (r->rsd.state == STATE_CELL)
+            {
+              char *value = CHAR_CAST (char *, xmlNodeGetContent (
+                                         xmlTextReaderExpand (r->rsd.xtr)));
+              if (idx >= n_var_specs)
+                {
+                  var_spec = xrealloc (var_spec, sizeof (*var_spec) * (idx + 1));
 
-	  if (r->rsd.state == STATE_CELL_CONTENT
-	      &&
-	      XML_READER_TYPE_TEXT  == r->rsd.node_type)
-	    {
-	      xmlChar *value = xmlTextReaderValue (r->rsd.xtr);
-	      if (idx >= n_var_specs)
-		{
-		  var_spec = xrealloc (var_spec, sizeof (*var_spec) * (idx + 1));
+                  /* xrealloc (unlike realloc) doesn't initialise its memory to 0 */
+                  memset (var_spec + n_var_specs,
+                          0,
+                          (idx - n_var_specs + 1) * sizeof (*var_spec));
+                  n_var_specs = idx + 1;
+                }
+              for (int i = 0; i < r->rsd.col_span; ++i)
+                {
+                  var_spec[idx - i].firstval.text = 0;
+                  var_spec[idx - i].firstval.value = 0;
+                  var_spec[idx - i].firstval.type = 0;
+                  var_spec[idx - i].name = xstrdup (value);
+                }
 
-		  /* xrealloc (unlike realloc) doesn't initialise its memory to 0 */
-		  memset (var_spec + n_var_specs,
-			  0,
-			  (idx - n_var_specs + 1) * sizeof (*var_spec));
-		  n_var_specs = idx + 1;
-		}
-	      for (int i = 0; i < r->rsd.col_span; ++i)
-		{
-		  var_spec[idx - i].firstval.text = 0;
-		  var_spec[idx - i].firstval.value = 0;
-		  var_spec[idx - i].firstval.type = 0;
-		  var_spec[idx - i].name =
-		    strdup (CHAR_CAST (const char *, value));
-		}
-
-	      xmlFree (value);
-	    }
-	}
+              xmlFree (value);
+            }
+        }
     }
 
   /* Read in the first row of data */
-  while (1 == xmlTextReaderRead (r->rsd.xtr))
+  while (process_node (r, &r->rsd))
     {
       int idx;
-      process_node (r, &r->rsd);
-
       if (! reading_target_sheet (r, &r->rsd))
-	break;
+        break;
 
       /* If the row is finished then stop for now */
       if (r->rsd.state == STATE_TABLE &&
-	  r->rsd.row > r->spreadsheet.start_row + (opts->read_names ? 1 : 0))
-	break;
+          r->rsd.row > r->spreadsheet.start_row + (opts->read_names ? 1 : 0))
+        break;
 
       idx = r->rsd.col - r->spreadsheet.start_col - 1;
       if (idx < 0)
-	continue;
+        continue;
 
       if (r->spreadsheet.stop_col != -1 && idx > r->spreadsheet.stop_col - r->spreadsheet.start_col)
-	continue;
+        continue;
 
       if (r->rsd.state == STATE_CELL &&
-	   XML_READER_TYPE_ELEMENT  == r->rsd.node_type)
-	{
-	  type = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value-type"));
-	  val_string = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value"));
-	}
+           XML_READER_TYPE_ELEMENT  == r->rsd.node_type)
+        {
+          type = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value-type"));
+          val_string = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value"));
+        }
 
-      if (r->rsd.state == STATE_CELL_CONTENT &&
-	   XML_READER_TYPE_TEXT  == r->rsd.node_type)
-	{
-	  if (idx >= n_var_specs)
-	    {
-	      var_spec = xrealloc (var_spec, sizeof (*var_spec) * (idx + r->rsd.col_span));
-	      memset (var_spec + n_var_specs,
-	              0,
-	              (idx + r->rsd.col_span - n_var_specs) * sizeof (*var_spec));
+      if (r->rsd.state == STATE_CELL)
+        {
+          if (idx >= n_var_specs)
+            {
+              var_spec = xrealloc (var_spec, sizeof (*var_spec) * (idx + r->rsd.col_span));
+              memset (var_spec + n_var_specs,
+                      0,
+                      (idx + r->rsd.col_span - n_var_specs) * sizeof (*var_spec));
 
-	      var_spec [idx].name = NULL;
-	      n_var_specs = idx + 1;
-	    }
+              var_spec [idx].name = NULL;
+              n_var_specs = idx + 1;
+            }
 
           for (int x = 0; x < r->rsd.col_span; ++x)
           {
             var_spec [idx - x].firstval.type = xmlStrdup (type);
-            var_spec [idx - x].firstval.text = xmlTextReaderValue (r->rsd.xtr);
+            var_spec [idx - x].firstval.text
+              = xmlNodeGetContent (xmlTextReaderExpand (r->rsd.xtr));
             var_spec [idx - x].firstval.value = xmlStrdup (val_string);
           }
 
           free (val_string);
           free (type);
-	}
+        }
     }
 
   /* Create the dictionary and populate it */
@@ -936,25 +847,20 @@ ods_make_reader (struct spreadsheet *spreadsheet,
 
   for (i = 0; i < n_var_specs ; ++i)
     {
+      int width = xmv_to_width (&var_spec[i].firstval, opts->asw);
+      struct variable *var = dict_create_var_with_unique_name (
+        r->spreadsheet.dict, var_spec[i].name, width);
+
       struct fmt_spec fmt;
-      struct variable *var = NULL;
-      char *name = dict_make_unique_var_name (r->spreadsheet.dict, var_spec[i].name, &vstart);
-      int width  = xmv_to_width (&var_spec[i].firstval, opts->asw);
-      dict_create_var (r->spreadsheet.dict, name, width);
-      free (name);
-
-      var = dict_get_var (r->spreadsheet.dict, i);
-
       if (0 == xmlStrcmp (var_spec[i].firstval.type, _xml("date")))
-	{
-	  fmt.type = FMT_DATE;
-	  fmt.d = 0;
-	  fmt.w = 20;
-	}
+        {
+          fmt.type = FMT_DATE;
+          fmt.d = 0;
+          fmt.w = 20;
+        }
       else
-	fmt = fmt_default_for_width (width);
-
-      var_set_both_formats (var, &fmt);
+        fmt = fmt_default_for_width (width);
+      var_set_both_formats (var, fmt);
     }
 
   if (n_var_specs ==  0)
@@ -974,19 +880,14 @@ ods_make_reader (struct spreadsheet *spreadsheet,
       const struct variable *var = dict_get_var (r->spreadsheet.dict, i);
 
       convert_xml_to_value (r->spreadsheet.first_case, var,  &var_spec[i].firstval,
-			    r->rsd.col - n_var_specs + i,
-			    r->rsd.row - 1);
+                            r->rsd.col - n_var_specs + i,
+                            r->rsd.row - 1);
     }
 
   /* Read in the first row of data */
-  while (1 == xmlTextReaderRead (r->rsd.xtr))
-    {
-      process_node (r, &r->rsd);
-
-      if (r->rsd.state == STATE_ROW)
-	break;
-    }
-
+  while (process_node (r, &r->rsd))
+    if (r->rsd.state == STATE_ROW)
+      break;
 
   for (i = 0 ; i < n_var_specs ; ++i)
     {
@@ -1042,13 +943,8 @@ ods_file_casereader_read (struct casereader *reader UNUSED, void *r_)
 
 
   /* Advance to the start of a row. (If there is one) */
-  while (r->rsd.state != STATE_ROW
-	 && 1 == xmlTextReaderRead (r->rsd.xtr)
-	)
-    {
-      process_node (r, &r->rsd);
-    }
-
+  while (r->rsd.state != STATE_ROW && process_node (r, &r->rsd))
+    continue;
 
   if (! reading_target_sheet (r, &r->rsd)
        ||  r->rsd.state < STATE_TABLE
@@ -1061,53 +957,50 @@ ods_file_casereader_read (struct casereader *reader UNUSED, void *r_)
   c = case_create (r->spreadsheet.proto);
   case_set_missing (c);
 
-  while (1 == xmlTextReaderRead (r->rsd.xtr))
+  while (process_node (r, &r->rsd))
     {
-      process_node (r, &r->rsd);
-
       if (r->spreadsheet.stop_row != -1 && r->rsd.row > r->spreadsheet.stop_row + 1)
-	break;
+        break;
 
       if (r->rsd.state == STATE_CELL &&
-	   r->rsd.node_type == XML_READER_TYPE_ELEMENT)
-	{
-	  type = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value-type"));
-	  val_string = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value"));
-	}
+           r->rsd.node_type == XML_READER_TYPE_ELEMENT)
+        {
+          type = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value-type"));
+          val_string = xmlTextReaderGetAttribute (r->rsd.xtr, _xml ("office:value"));
+        }
 
-      if (r->rsd.state == STATE_CELL_CONTENT &&
-	   r->rsd.node_type == XML_READER_TYPE_TEXT)
-	{
-	  int col;
-	  struct xml_value *xmv = XZALLOC (struct xml_value);
-	  xmv->text = xmlTextReaderValue (r->rsd.xtr);
-	  xmv->value = val_string;
-	  val_string = NULL;
-	  xmv->type = type;
-	  type = NULL;
+      if (r->rsd.state == STATE_CELL)
+        {
+          int col;
+          struct xml_value *xmv = XZALLOC (struct xml_value);
+          xmv->text = xmlNodeGetContent (xmlTextReaderExpand (r->rsd.xtr));
+          xmv->value = val_string;
+          val_string = NULL;
+          xmv->type = type;
+          type = NULL;
 
-	  for (col = 0; col < r->rsd.col_span; ++col)
-	    {
-	      const struct variable *var;
-	      const int idx = r->rsd.col - col - r->spreadsheet.start_col - 1;
-	      if (idx < 0)
-		continue;
-	      if (r->spreadsheet.stop_col != -1 && idx > r->spreadsheet.stop_col - r->spreadsheet.start_col)
-		break;
-	      if (idx >= dict_get_n_vars (r->spreadsheet.dict))
-		break;
+          for (col = 0; col < r->rsd.col_span; ++col)
+            {
+              const struct variable *var;
+              const int idx = r->rsd.col - col - r->spreadsheet.start_col - 1;
+              if (idx < 0)
+                continue;
+              if (r->spreadsheet.stop_col != -1 && idx > r->spreadsheet.stop_col - r->spreadsheet.start_col)
+                break;
+              if (idx >= dict_get_n_vars (r->spreadsheet.dict))
+                break;
 
               var = dict_get_var (r->spreadsheet.dict, idx);
-	      convert_xml_to_value (c, var, xmv, idx + r->spreadsheet.start_col, r->rsd.row - 1);
-	    }
+              convert_xml_to_value (c, var, xmv, idx + r->spreadsheet.start_col, r->rsd.row - 1);
+            }
 
-	  xmlFree (xmv->text);
-	  xmlFree (xmv->value);
-	  xmlFree (xmv->type);
-	  free (xmv);
-	}
+          xmlFree (xmv->text);
+          xmlFree (xmv->value);
+          xmlFree (xmv->type);
+          free (xmv);
+        }
       if (r->rsd.state <= STATE_TABLE)
-	break;
+        break;
     }
 
   xmlFree (type);
@@ -1129,20 +1022,20 @@ init_reader (struct ods_reader *r, bool report_errors,
       if (content == NULL)
         {
           free (error);
-          return NULL;
+          return false;
         }
 
       xmlTextReaderPtr xtr = xmlReaderForIO (xml_reader_for_zip_member, NULL, content, NULL, NULL,
-					     report_errors
-					     ? 0
-					     : (XML_PARSE_NOERROR | XML_PARSE_NOWARNING));
+                                             report_errors
+                                             ? 0
+                                             : (XML_PARSE_NOERROR | XML_PARSE_NOWARNING));
 
       if (xtr == NULL)
-	return false;
+        return false;
 
      *state = (struct state_data) { .xtr = xtr,
-				    .zm = content,
-				    .state = STATE_INIT };
+                                    .zm = content,
+                                    .state = STATE_INIT };
      if (report_errors)
        xmlTextReaderSetErrorHandler (xtr, ods_error_handler, r);
   }
@@ -1163,38 +1056,42 @@ init_reader (struct ods_reader *r, bool report_errors,
 struct spreadsheet *
 ods_probe (const char *filename, bool report_errors)
 {
-  struct ods_reader *r = XZALLOC (struct ods_reader);
-
   struct zip_reader *zr;
   char *error = zip_reader_create (filename, &zr);
   if (error)
     {
       if (report_errors)
-	{
-	  msg (ME, _("Cannot open %s as a OpenDocument file: %s"),
-	       filename, error);
-	}
+        msg (ME, _("Cannot open %s as a OpenDocument file: %s"),
+             filename, error);
       free (error);
-      free (r);
+      return NULL;
+    }
+  if (!zip_reader_contains_member (zr, "meta.xml")
+      || !zip_reader_contains_member (zr, "content.xml"))
+    {
+      if (report_errors)
+        msg (ME, _("%s is not an OpenDocument file."), filename);
+      zip_reader_unref (zr);
       return NULL;
     }
 
-  r->zreader = zr;
-  r->spreadsheet.ref_cnt = 1;
-  hmap_init (&r->cache);
+  struct ods_reader *r = xmalloc (sizeof *r);
+  *r = (struct ods_reader) {
+    .zreader = zr,
+    .cache = HMAP_INITIALIZER (r->cache),
+    .n_sheets = -1,
+    .spreadsheet = {
+      .ref_cnt = 1,
+      .file_name = xstrdup (filename),
+    },
+  };
 
   if (!init_reader (r, report_errors, NULL))
     goto error;
 
-  r->n_sheets = -1;
-  r->n_allocated_sheets = 0;
-  r->spreadsheet.sheets = NULL;
-
-  r->spreadsheet.file_name = strdup (filename);
   return &r->spreadsheet;
 
  error:
-  zip_reader_unref (r->zreader);
-  free (r);
+  ods_destroy (&r->spreadsheet);
   return NULL;
 }
