@@ -73,12 +73,12 @@ struct pfm_reader
     struct any_read_info info;
     struct file_handle *fh;     /* File handle. */
     struct fh_lock *lock;       /* Read lock for file. */
-    FILE *file;			/* File stream. */
+    FILE *file;                        /* File stream. */
     int line_length;            /* Number of characters so far on this line. */
-    char cc;			/* Current character. */
+    char cc;                        /* Current character. */
     char *trans;                /* 256-byte character set translation table. */
     int n_vars;                 /* Number of variables. */
-    int weight_index;		/* 0-based index of weight variable, or -1. */
+    int weight_index;                /* 0-based index of weight variable, or -1. */
     struct caseproto *proto;    /* Format of output cases. */
     bool ok;                    /* Set false on I/O error. */
   };
@@ -125,7 +125,7 @@ error (struct pfm_reader *r, const char *msg, ...)
   longjmp (r->bail_out, 1);
 }
 
-/* Displays MSG as an warning for the current position in
+/* Displays MSG as a warning for the current position in
    portable file reader R. */
 static void
 warning (struct pfm_reader *r, const char *msg, ...)
@@ -215,7 +215,7 @@ advance (struct pfm_reader *r)
       r->line_length = 0;
     }
   if (c == EOF)
-    error (r, _("unexpected end of file"));
+    error (r, _("Unexpected end of file"));
 
   if (r->trans != NULL)
     c = r->trans[c];
@@ -359,7 +359,7 @@ read_float (struct pfm_reader *r)
   /* `*' indicates system-missing. */
   if (match (r, '*'))
     {
-      advance (r);	/* Probably a dot (.) but doesn't appear to matter. */
+      advance (r);        /* Probably a dot (.) but doesn't appear to matter. */
       return SYSMIS;
     }
 
@@ -368,33 +368,33 @@ read_float (struct pfm_reader *r)
     {
       int digit = base_30_value (r->cc);
       if (digit != -1)
-	{
-	  got_digit = true;
+        {
+          got_digit = true;
 
-	  /* Make sure that multiplication by 30 will not overflow.  */
-	  if (num > DBL_MAX * (1. / 30.))
-	    /* The value of the digit doesn't matter, since we have already
-	       gotten as many digits as can be represented in a `double'.
-	       This doesn't necessarily mean the result will overflow.
-	       The exponent may reduce it to within range.
+          /* Make sure that multiplication by 30 will not overflow.  */
+          if (num > DBL_MAX * (1. / 30.))
+            /* The value of the digit doesn't matter, since we have already
+               gotten as many digits as can be represented in a `double'.
+               This doesn't necessarily mean the result will overflow.
+               The exponent may reduce it to within range.
 
-	       We just need to record that there was another
-	       digit so that we can multiply by 10 later.  */
-	    ++exponent;
-	  else
-	    num = (num * 30.0) + digit;
+               We just need to record that there was another
+               digit so that we can multiply by 10 later.  */
+            ++exponent;
+          else
+            num = (num * 30.0) + digit;
 
-	  /* Keep track of the number of digits after the decimal point.
-	     If we just divided by 30 here, we would lose precision.  */
-	  if (got_dot)
-	    --exponent;
-	}
+          /* Keep track of the number of digits after the decimal point.
+             If we just divided by 30 here, we would lose precision.  */
+          if (got_dot)
+            --exponent;
+        }
       else if (!got_dot && r->cc == '.')
-	/* Record that we have found the decimal point.  */
-	got_dot = 1;
+        /* Record that we have found the decimal point.  */
+        got_dot = 1;
       else
-	/* Any other character terminates the number.  */
-	break;
+        /* Any other character terminates the number.  */
+        break;
 
       advance (r);
     }
@@ -411,19 +411,19 @@ read_float (struct pfm_reader *r)
       int digit;
 
       for (advance (r); (digit = base_30_value (r->cc)) != -1; advance (r))
-	{
-	  if (exp > LONG_MAX / 30)
+        {
+          if (exp > LONG_MAX / 30)
             {
               exp = LONG_MAX;
               break;
             }
-	  exp = exp * 30 + digit;
-	}
+          exp = exp * 30 + digit;
+        }
 
       /* We don't check whether there were actually any digits, but we
          probably should. */
       if (negative_exponent)
-	exp = -exp;
+        exp = -exp;
       exponent += exp;
     }
 
@@ -623,32 +623,23 @@ static struct fmt_spec
 convert_format (struct pfm_reader *r, const int portable_format[3],
                 struct variable *v, bool *report_error)
 {
-  struct fmt_spec format;
-  bool ok;
-
-  if (!fmt_from_io (portable_format[0], &format.type))
+  enum fmt_type type;
+  if (fmt_from_io (portable_format[0], &type))
     {
-      if (*report_error)
-        warning (r, _("%s: Bad format specifier byte (%d).  Variable "
-                      "will be assigned a default format."),
-                 var_get_name (v), portable_format[0]);
-      goto assign_default;
-    }
+      struct fmt_spec format = {
+        .type = type,
+        .w = portable_format[1],
+        .d = portable_format[2],
+      };
 
-  format.w = portable_format[1];
-  format.d = portable_format[2];
+      if (fmt_check_output (format)
+          && fmt_check_width_compat (format, var_get_width (v)))
+        return format;
 
-  msg_disable ();
-  ok = (fmt_check_output (&format)
-        && fmt_check_width_compat (&format, var_get_width (v)));
-  msg_enable ();
-
-  if (!ok)
-    {
       if (*report_error)
         {
           char fmt_string[FMT_STRING_LEN_MAX + 1];
-          fmt_to_string (&format, fmt_string);
+          fmt_to_string (format, fmt_string);
           if (var_is_numeric (v))
             warning (r, _("Numeric variable %s has invalid format "
                           "specifier %s."),
@@ -658,12 +649,15 @@ convert_format (struct pfm_reader *r, const int portable_format[3],
                           "invalid format specifier %s."),
                      var_get_name (v), var_get_width (v), fmt_string);
         }
-      goto assign_default;
+    }
+  else
+    {
+      if (*report_error)
+        warning (r, _("%s: Bad format specifier byte (%d).  Variable "
+                      "will be assigned a default format."),
+                 var_get_name (v), portable_format[0]);
     }
 
-  return format;
-
-assign_default:
   *report_error = false;
   return fmt_default_for_width (var_get_width (v));
 }
@@ -706,44 +700,28 @@ read_variables (struct pfm_reader *r, struct dictionary *dict)
       int j;
 
       if (!match (r, '7'))
-	error (r, _("Expected variable record."));
+        error (r, _("Expected variable record."));
 
       width = read_int (r);
       if (width < 0)
-	error (r, _("Invalid variable width %d."), width);
+        error (r, _("Invalid variable width %d."), width);
 
       read_string (r, name);
       for (j = 0; j < 6; j++)
         fmt[j] = read_int (r);
 
-      if (!dict_id_is_valid (dict, name, false)
-          || *name == '#' || *name == '$')
-        error (r, _("Invalid variable name `%s' in position %d."), name, i);
-      str_uppercase (name);
-
       if (width < 0 || width > 255)
-	error (r, _("Bad width %d for variable %s."), width, name);
+        error (r, _("Bad width %d for variable %s."), width, name);
 
-      v = dict_create_var (dict, name, width);
-      if (v == NULL)
-        {
-          unsigned long int i;
-          for (i = 1; ; i++)
-            {
-              char *try_name = xasprintf ("%s_%lu", name, i);
-              v = dict_create_var (dict, try_name, width);
-              free (try_name);
-              if (v != NULL)
-                break;
-            }
-          warning (r, _("Duplicate variable name %s in position %d renamed "
-                        "to %s."), name, i, var_get_name (v));
-        }
+      v = dict_create_var_with_unique_name (dict, name, width);
+      if (utf8_strcasecmp (name, var_get_name (v)))
+        warning (r, _("Invalid or duplicate variable name %s in position %d "
+                      "renamed to %s."), name, i, var_get_name (v));
 
       print = convert_format (r, &fmt[0], v, &report_error);
       write = convert_format (r, &fmt[3], v, &report_error);
-      var_set_print_format (v, &print);
-      var_set_write_format (v, &write);
+      var_set_print_format (v, print);
+      var_set_write_format (v, write);
 
       /* Range missing values. */
       mv_init (&miss, width);
@@ -829,12 +807,12 @@ read_value_label (struct pfm_reader *r, struct dictionary *dict)
 
       v[i] = dict_lookup_var (dict, name);
       if (v[i] == NULL)
-	error (r, _("Unknown variable %s while parsing value labels."), name);
+        error (r, _("Unknown variable %s while parsing value labels."), name);
 
       if (var_get_type (v[0]) != var_get_type (v[i]))
-	error (r, _("Cannot assign value labels to %s and %s, which "
-		    "have different variable types."),
-	       var_get_name (v[0]), var_get_name (v[i]));
+        error (r, _("Cannot assign value labels to %s and %s, which "
+                    "have different variable types."),
+               var_get_name (v[0]), var_get_name (v[i]));
     }
 
   n_labels = read_int (r);
