@@ -23,6 +23,7 @@
 #include "libpspp/compiler.h"
 
 struct string;
+struct substring;
 
 /* What kind of message is this? */
 enum msg_category
@@ -47,9 +48,9 @@ const char *msg_severity_to_string (enum msg_severity);
 /* Combination of a category and a severity for convenience. */
 enum msg_class
   {
-    ME, MW, MN,			/* General error/warning/note. */
-    SE, SW, SN,			/* Script error/warning/note. */
-    DE, DW, DN,			/* Data-file error/note. */
+    ME, MW, MN,                        /* General error/warning/note. */
+    SE, SW, SN,                        /* Script error/warning/note. */
+    DE, DW, DN,                        /* Data-file error/note. */
     MSG_CLASS_CNT,
   };
 
@@ -85,6 +86,8 @@ struct msg_point
     int column;
   };
 
+struct msg_point msg_point_advance (struct msg_point, struct substring);
+
 /* Location of the cause of an error. */
 struct msg_location
   {
@@ -109,6 +112,11 @@ struct msg_location
        Both 'start' and 'end' are inclusive, line-wise and column-wise.
     */
     struct msg_point start, end;
+
+    /* Normally, 'start' and 'end' contain column information, then displaying
+       the message will underline the location.  Setting this to true disables
+       displaying underlines. */
+    bool omit_underlines;
   };
 
 void msg_location_uninit (struct msg_location *);
@@ -118,6 +126,8 @@ struct msg_location *msg_location_dup (const struct msg_location *);
 void msg_location_remove_columns (struct msg_location *);
 
 void msg_location_merge (struct msg_location **, const struct msg_location *);
+struct msg_location *msg_location_merged (const struct msg_location *,
+                                          const struct msg_location *);
 
 bool msg_location_is_empty (const struct msg_location *);
 void msg_location_format (const struct msg_location *, struct string *);
@@ -149,7 +159,7 @@ struct msg_handler
     void (*output_msg) (const struct msg *, void *aux);
     void *aux;
 
-    void (*lex_source_ref) (const struct lex_source *);
+    struct lex_source *(*lex_source_ref) (const struct lex_source *);
     void (*lex_source_unref) (struct lex_source *);
     struct substring (*lex_source_get_line) (const struct lex_source *,
                                              int line);
