@@ -25,6 +25,7 @@
 #include <stdlib.h>
 #include <unistr.h>
 
+#include "libpspp/assertion.h"
 #include "libpspp/cast.h"
 #include "libpspp/i18n.h"
 #include "libpspp/message.h"
@@ -262,10 +263,14 @@ str_lowercase (char *s)
    which has room for SIZE bytes.  Uses uppercase if UPPERCASE is
    true, otherwise lowercase, Returns true if successful, false
    if NUMBER, plus a trailing null, is too large to fit in the
-   available space.
+   available space.  If SIZE is at least F26ADIC_STRLEN_MAX + 1,
+   the number is guaranteed to fit.  Even if the number doesn't
+   fit, if SIZE > 0, the characters that do fit, if any, will be
+   null-terminated.
 
    26-adic notation is "spreadsheet column numbering": 1 = A, 2 =
-   B, 3 = C, ... 26 = Z, 27 = AA, 28 = AB, 29 = AC, ...
+   B, 3 = C, ... 26 = Z, 27 = AA, 28 = AB, 29 = AC, ...  Zero is
+   the empty string.
 
    26-adic notation is the special case of a k-adic numeration
    system (aka bijective base-k numeration) with k=26.  In k-adic
@@ -274,8 +279,8 @@ str_lowercase (char *s)
    For more information, see
    http://en.wikipedia.org/wiki/Bijective_numeration. */
 bool
-str_format_26adic (unsigned long int number, bool uppercase,
-                   char buffer[], size_t size)
+str_format_26adic__ (unsigned long int number, bool uppercase,
+                     char buffer[], size_t size)
 {
   const char *alphabet
     = uppercase ? "ABCDEFGHIJKLMNOPQRSTUVWXYZ" : "abcdefghijklmnopqrstuvwxyz";
@@ -302,6 +307,50 @@ overflow:
   return false;
 }
 
+/* Like str_format_26adic__(), but SIZE must be big enough that it cannot
+   fail. */
+void
+str_format_26adic (unsigned long int number, bool uppercase,
+                   char buffer[], size_t size)
+{
+  assert (size >= F26ADIC_STRLEN_MAX + 1);
+  if (!str_format_26adic__ (number, uppercase, buffer, size))
+    NOT_REACHED ();
+}
+
+/* Returns the value of 26-adic string STR.  See str_format_26adic() for a
+   definition of 26-adic.
+
+   On error, this function returns -1. */
+int
+str_parse_26adic (const char *str)
+{
+  enum { RADIX = 26 };
+
+  int multiplier = 1;
+  int result = 0;
+
+  size_t len = strlen (str);
+  for (size_t i = 0; i < len; i++)
+    {
+      if (result >= INT_MAX / RADIX)
+        return -1;
+
+      char c = str[len - i - 1];
+      int digit = (c >= 'A' && c <= 'Z' ? c - 'A'
+                   : c >= 'a' && c <= 'z' ? c - 'a'
+                   : -1);
+      if (digit < 0)
+        return -1;
+      assert (digit >= 0 && digit < RADIX);
+
+      result += (digit + (i > 0)) * multiplier;
+      multiplier *= RADIX;
+    }
+
+  return result;
+}
+
 /* Copies IN to buffer OUT with size OUT_SIZE, appending a null terminator.  If
    IN is too long for OUT, or if IN contains a new-line, replaces the tail with
    "...".
@@ -376,13 +425,15 @@ ss_tail (struct substring ss, size_t n)
     return ss;
 }
 
-/* Makes a malloc()'d, null-terminated copy of the contents of OLD
-   and stores it in NEW. */
-void
-ss_alloc_substring (struct substring *new, struct substring old)
+/* Returns a malloc()'d, null-terminated copy of the contents of OLD.  The
+  caller owns the returned string and must eventually free it. */
+struct substring
+ss_clone (struct substring old)
 {
-  new->string = xmemdup0 (old.string, old.length);
-  new->length = old.length;
+  return (struct substring) {
+    .string = xmemdup0 (old.string, old.length),
+    .length = old.length,
+  };
 }
 
 /* Allocates room for a N-byte string in NEW. */
@@ -399,16 +450,15 @@ ss_realloc (struct substring *ss, size_t size)
   ss->string = xrealloc (ss->string, size);
 }
 
-/* Makes a pool_alloc_unaligned()'d, null-terminated copy of the contents of
-   OLD in POOL, and stores it in NEW. */
-void
-ss_alloc_substring_pool (struct substring *new, struct substring old,
-                         struct pool *pool)
+/* Returns a pool_alloc_unaligned()'d, null-terminated copy of the contents of
+  OLD in POOL.  The pool owns the returned string. */
+struct substring
+ss_clone_pool (struct substring old, struct pool *pool)
 {
-  new->string = pool_alloc_unaligned (pool, old.length + 1);
-  new->length = old.length;
-  memcpy (new->string, old.string, old.length);
-  new->string[old.length] = '\0';
+  return (struct substring) {
+    .string = pool_memdup0 (pool, old.string, old.length),
+    .length = old.length
+  };
 }
 
 /* Allocates room for a N-byte string in NEW in POOL. */
@@ -615,6 +665,21 @@ ss_match_string (struct substring *ss, const struct substring target)
     return false;
 }
 
+/* If SS begins with TARGET, except possibly for case differences, removes it
+   and returns true.  Otherwise, returns false without changing SS. */
+bool
+ss_match_string_case (struct substring *ss, const struct substring target)
+{
+  size_t length = ss_length (target);
+  if (ss_equals_case (ss_head (*ss, length), target))
+    {
+      ss_advance (ss, length);
+      return true;
+    }
+  else
+    return false;
+}
+
 /* Removes the first byte from SS and returns it.
    If SS is empty, returns EOF without modifying SS. */
 int
@@ -743,6 +808,14 @@ ss_starts_with (struct substring ss, struct substring prefix)
           && !memcmp (ss.string, prefix.string, prefix.length));
 }
 
+/* Returns true if SS starts with PREFIX in any case, false otherwise. */
+bool
+ss_starts_with_case (struct substring ss, struct substring prefix)
+{
+  return (ss.length >= prefix.length
+          && !memcasecmp (ss.string, prefix.string, prefix.length));
+}
+
 /* Returns true if SS ends with SUFFIX, false otherwise. */
 bool
 ss_ends_with (struct substring ss, struct substring suffix)
@@ -752,6 +825,15 @@ ss_ends_with (struct substring ss, struct substring suffix)
                       suffix.length));
 }
 
+/* Returns true if SS ends with SUFFIX in any case, false otherwise. */
+bool
+ss_ends_with_case (struct substring ss, struct substring suffix)
+{
+  return (ss.length >= suffix.length
+          && !memcasecmp (&ss.string[ss.length - suffix.length], suffix.string,
+                          suffix.length));
+}
+
 /* Returns the number of contiguous bytes at the beginning
    of SS that are in SKIP_SET. */
 size_t
@@ -806,6 +888,15 @@ ss_compare (struct substring a, struct substring b)
   return retval;
 }
 
+/* Compares A to B and returns a strcmp()-type comparison result.  The shorter
+   string is considered to be padded with spaces to the length of the
+   longer. */
+int
+ss_compare_rpad (struct substring a, struct substring b)
+{
+  return buf_compare_rpad (a.string, a.length, b.string, b.length);
+}
+
 /* Compares A and B case-insensitively and returns a
    strcmp()-type comparison result. */
 int
@@ -1104,7 +1195,7 @@ ds_extend (struct string *st, size_t min_capacity)
     {
       st->capacity *= 2;
       if (st->capacity < min_capacity)
-	st->capacity = 2 * min_capacity;
+        st->capacity = 2 * min_capacity;
 
       st->ss.string = xrealloc (st->ss.string, st->capacity + 1);
     }
@@ -1677,6 +1768,18 @@ ds_put_unichar (struct string *st, ucs4_t uc)
   st->ss.length += u8_uctomb (CHAR_CAST (uint8_t *, ds_end (st)), uc, 6);
 }
 
+/* Appends N copies of S to ST. */
+void
+ds_put_substring_multiple (struct string *dst, struct substring src, size_t n)
+{
+  char *p = ds_put_uninit (dst, n * src.length);
+  for (size_t i = 0; i < n; i++)
+    {
+      memcpy (p, src.string, src.length);
+      p += src.length;
+    }
+}
+
 /* If relocation has been enabled, replace ST,
    with its relocated version */
 void
@@ -1690,12 +1793,35 @@ ds_relocate (struct string *st)
       ds_clear (st);
       ds_put_cstr (st, rel);
       /* The documentation for relocate says that casting away const
-	and then freeing is appropriate ... */
+        and then freeing is appropriate ... */
       free (CONST_CAST (char *, rel));
     }
 }
 
+/* Returns a relocated version of S as a malloc()'d string that the caller must
+   eventually free(). */
+char *
+relocate_clone (const char *s)
+{
+  char *r = CONST_CAST (char *, relocate (s));
+  return r != s ? r : xstrdup (s);
+}
 
+/* Formats FORMAT in a printf()-like manner and returns a relocated version of
+   it.  The caller must eventually free() the returned string. */
+char * PRINTF_FORMAT (1, 2) MALLOC_LIKE
+relocate_format (const char *format, ...)
+{
+  va_list args;
+  va_start (args, format);
+  char *s = xvasprintf (format, args);
+  va_end (args);
+
+  char *r = CONST_CAST (char *, relocate (s));
+  if (r != s)
+    free (s);
+  return r;
+}
 
 
 /* Operations on uint8_t "strings" */
@@ -1705,8 +1831,8 @@ ds_relocate (struct string *st)
    copies of PAD as needed. */
 void
 u8_buf_copy_rpad (uint8_t *dst, size_t dst_size,
-		  const uint8_t *src, size_t src_size,
-		  char pad)
+                  const uint8_t *src, size_t src_size,
+                  char pad)
 {
   if (src_size >= dst_size)
     memmove (dst, src, dst_size);
