@@ -19,7 +19,6 @@
 
 #include "order-stats.h"
 
-struct moments1;
 struct casewriter;
 
 enum
@@ -30,6 +29,8 @@ enum
     n_NP_IDX
   };
 
+/* Statistics needed to produce a normal probability plot with
+   np_plot_create(). */
 struct np
 {
   struct order_stats parent;
@@ -38,7 +39,6 @@ struct np
   double mean;
   double stddev;
 
-
   double prev_cc;
 
   double ns_min;
@@ -53,7 +53,6 @@ struct np
   struct casewriter *writer;
 };
 
-
-struct np * np_create (const struct moments1 *);
+struct np *np_create (double n, double mean, double var);
 
 #endif
