@@ -84,11 +84,10 @@ html_driver_cast (struct output_driver *driver)
   return UP_CAST (driver, struct html_driver, driver);
 }
 
-static struct driver_option *
-opt (struct output_driver *d, struct string_map *options, const char *key,
-     const char *default_value)
+static struct driver_option
+opt (struct driver_options *options, const char *key, const char *default_value)
 {
-  return driver_option_get (d, options, key, default_value);
+  return driver_option_get (options, key, default_value);
 }
 
 static void
@@ -110,66 +109,66 @@ put_header (struct html_driver *html)
   if (html->css)
     {
       fputs ("<style>\n"
-	     "<!--\n"
-	     "body {\n"
-	     "  background: white;\n"
-	     "  color: black;\n"
-	     "  padding: 0em 12em 0em 3em;\n"
-	     "  margin: 0\n"
-	     "}\n"
-	     "body>p {\n"
-	     "  margin: 0pt 0pt 0pt 0em\n"
-	     "}\n"
-	     "body>p + p {\n"
-	     "  text-indent: 1.5em;\n"
-	     "}\n"
-	     "h1 {\n"
-	     "  font-size: 150%;\n"
-	     "  margin-left: -1.33em\n"
-	     "}\n"
-	     "h2 {\n"
-	     "  font-size: 125%;\n"
-	     "  font-weight: bold;\n"
-	     "  margin-left: -.8em\n"
-	     "}\n"
-	     "h3 {\n"
-	     "  font-size: 100%;\n"
-	     "  font-weight: bold;\n"
-	     "  margin-left: -.5em }\n"
-	     "h4 {\n"
-	     "  font-size: 100%;\n"
-	     "  margin-left: 0em\n"
-	     "}\n"
-	     "h1, h2, h3, h4, h5, h6 {\n"
-	     "  font-family: sans-serif;\n"
-	     "  color: blue\n"
-	     "}\n"
-	     "html {\n"
-	     "  margin: 0\n"
-	     "}\n"
-	     "code {\n"
-	     "  font-family: sans-serif\n"
-	     "}\n"
-	     "table {\n"
-	     "  border-collapse: collapse;\n"
-	     "  margin-bottom: 1em\n"
-	     "}\n"
-	     "caption {\n"
-	     "  text-align: left\n"
-	     "}\n"
-	     "th { font-weight: normal }\n"
-	     "a:link {\n"
-	     "  color: #1f00ff;\n"
-	     "}\n"
-	     "a:visited {\n"
-	     "  color: #9900dd;\n"
-	     "}\n"
-	     "a:active {\n"
-	     "  color: red;\n"
-	     "}\n"
-	     "-->\n"
-	     "</style>\n",
-	     html->file);
+             "<!--\n"
+             "body {\n"
+             "  background: white;\n"
+             "  color: black;\n"
+             "  padding: 0em 12em 0em 3em;\n"
+             "  margin: 0\n"
+             "}\n"
+             "body>p {\n"
+             "  margin: 0pt 0pt 0pt 0em\n"
+             "}\n"
+             "body>p + p {\n"
+             "  text-indent: 1.5em;\n"
+             "}\n"
+             "h1 {\n"
+             "  font-size: 150%;\n"
+             "  margin-left: -1.33em\n"
+             "}\n"
+             "h2 {\n"
+             "  font-size: 125%;\n"
+             "  font-weight: bold;\n"
+             "  margin-left: -.8em\n"
+             "}\n"
+             "h3 {\n"
+             "  font-size: 100%;\n"
+             "  font-weight: bold;\n"
+             "  margin-left: -.5em }\n"
+             "h4 {\n"
+             "  font-size: 100%;\n"
+             "  margin-left: 0em\n"
+             "}\n"
+             "h1, h2, h3, h4, h5, h6 {\n"
+             "  font-family: sans-serif;\n"
+             "  color: blue\n"
+             "}\n"
+             "html {\n"
+             "  margin: 0\n"
+             "}\n"
+             "code {\n"
+             "  font-family: sans-serif\n"
+             "}\n"
+             "table {\n"
+             "  border-collapse: collapse;\n"
+             "  margin-bottom: 1em\n"
+             "}\n"
+             "caption {\n"
+             "  text-align: left\n"
+             "}\n"
+             "th { font-weight: normal }\n"
+             "a:link {\n"
+             "  color: #1f00ff;\n"
+             "}\n"
+             "a:visited {\n"
+             "  color: #9900dd;\n"
+             "}\n"
+             "a:active {\n"
+             "  color: red;\n"
+             "}\n"
+             "-->\n"
+             "</style>\n",
+             html->file);
     }
   fputs ("</head>\n", html->file);
   fputs ("<body>\n", html->file);
@@ -177,39 +176,39 @@ put_header (struct html_driver *html)
 
 static struct output_driver *
 html_create (struct file_handle *fh, enum settings_output_devices device_type,
-             struct string_map *o)
+             struct driver_options *o)
 {
-  struct output_driver *d;
-  struct html_driver *html = XZALLOC (struct html_driver);
-  d = &html->driver;
-  output_driver_init (&html->driver, &html_driver_class, fh_get_file_name (fh),
-                      device_type);
-  html->bare = parse_boolean (opt (d, o, "bare", "false"));
-  html->css = parse_boolean (opt (d, o, "css", "true"));
-  html->borders = parse_boolean (opt (d, o, "borders", "true"));
-
-  html->handle = fh;
-  html->chart_file_name = parse_chart_file_name (opt (d, o, "charts",
-                                                      fh_get_file_name (fh)));
-  html->file = NULL;
-  html->n_charts = 1;
-  html->bg = parse_color (opt (d, o, "background-color", "#FFFFFFFFFFFF"));
-  html->fg = parse_color (opt (d, o, "foreground-color", "#000000000000"));
-  html->file = fn_open (html->handle, "w");
-  if (html->file == NULL)
+  FILE *file = fn_open (fh, "w");
+  if (!file)
     {
-      msg_error (errno, _("error opening output file `%s'"), fh_get_file_name (html->handle));
-      goto error;
+      msg_error (errno, _("error opening output file `%s'"),
+                 fh_get_file_name (fh));
+      return NULL;
     }
 
+  struct html_driver *html = xmalloc (sizeof *html);
+  *html = (struct html_driver) {
+    .driver = {
+      .class = &html_driver_class,
+      .name = xstrdup (fh_get_file_name (fh)),
+      .device_type = device_type
+    },
+    .bare = parse_boolean (opt (o, "bare", "false")),
+    .css = parse_boolean (opt (o, "css", "true")),
+    .borders = parse_boolean (opt (o, "borders", "true")),
+    .handle = fh,
+    .chart_file_name = parse_chart_file_name (opt (o, "charts",
+                                                   fh_get_file_name (fh))),
+    .file = file,
+    .n_charts = 1,
+    .bg = parse_color (opt (o, "background-color", "#FFFFFFFFFFFF")),
+    .fg = parse_color (opt (o, "foreground-color", "#000000000000")),
+  };
+
   if (!html->bare)
     put_header (html);
 
-  return d;
-
- error:
-  output_driver_destroy (d);
-  return NULL;
+  return &html->driver;
 }
 
 /* Emits <NAME>CONTENT</NAME> to the output, escaping CONTENT as
@@ -454,7 +453,7 @@ format_color (const struct cell_color color,
               const struct cell_color default_color,
               char *buf, size_t bufsize)
 {
-  bool retval = !cell_color_equal (&color, &default_color);
+  bool retval = !cell_color_equal (color, default_color);
   if (retval)
     {
       if (color.alpha == 255)
@@ -472,16 +471,16 @@ put_border (const struct table *table, const struct table_cell *cell,
             enum table_axis axis, int h, int v,
             const char *border_name)
 {
-  struct cell_color color;
-  const char *css = border_to_css (
-    table_get_rule (table, axis, cell->d[H][h], cell->d[V][v], &color));
+  struct table_border_style border
+    = table_get_rule (table, axis, cell->d[H][h], cell->d[V][v]);
+  const char *css = border_to_css (border.stroke);
   if (css)
     {
       next_style (style);
       fprintf (style->file, "border-%s: %s", border_name, css);
 
       char buf[32];
-      if (format_color (color, (struct cell_color) CELL_COLOR_BLACK,
+      if (format_color (border.color, (struct cell_color) CELL_COLOR_BLACK,
                         buf, sizeof buf))
         fprintf (style->file, " %s", buf);
     }
@@ -516,7 +515,7 @@ html_put_table_cell (struct html_driver *html, const struct pivot_table *pt,
       break;
     }
 
-  if (cell->options & TAB_ROTATE)
+  if (cell->options & TABLE_CELL_ROTATE)
     put_style (&style, "writing-mode", "sideways-lr");
 
   if (cell->cell_style->valign != TABLE_VALIGN_TOP)
@@ -543,7 +542,9 @@ html_put_table_cell (struct html_driver *html, const struct pivot_table *pt,
     {
       put_style (&style, "font-family", "\"");
       escape_string (html->file, fs->typeface, " ", "\n");
-      putc ('"', html->file);
+
+      /* Always include a generic font family name as a fallback. */
+      fputs ("\", sans-serif", html->file);
     }
   if (fs->bold)
     put_style (&style, "font-weight", "bold");
