@@ -23,17 +23,6 @@
 
 struct table_item;
 
-enum render_line_style
-  {
-    RENDER_LINE_NONE,
-    RENDER_LINE_SINGLE,
-    RENDER_LINE_DASHED,
-    RENDER_LINE_THICK,
-    RENDER_LINE_THIN,
-    RENDER_LINE_DOUBLE,
-    RENDER_N_LINES
-  };
-
 /* Parameters for rendering a table_item to a device.
 
 
@@ -66,6 +55,11 @@ struct render_params
     /* Width of different kinds of lines. */
     const int *line_widths;           /* RENDER_N_LINES members. */
 
+    /* 1/96" of an inch (1px) in the rendering unit.  Currently used only for
+       column width ranges (as specified in width_ranges in struct
+       pivot_table_look).  Set to 0 to disable this feature. */
+    int px_size;
+
     /* Minimum cell width or height before allowing the cell to be broken
        across two pages.  (Joined cells may always be broken at join
        points.) */
@@ -123,8 +117,7 @@ struct render_ops
        STYLES[TABLE_VERT][0]: style of line from left of BB to its center.
        STYLES[TABLE_VERT][1]: style of line from right of BB to its center. */
     void (*draw_line) (void *aux, int bb[TABLE_N_AXES][2],
-                       enum render_line_style styles[TABLE_N_AXES][2],
-                       struct cell_color colors[TABLE_N_AXES][2]);
+                       const struct table_border_style styles[TABLE_N_AXES][2]);
 
     /* Draws CELL within bounding box BB.  CLIP is the same as BB (the common
        case) or a subregion enclosed by BB.  In the latter case only the part
