@@ -19,6 +19,7 @@
 
 #include "pre-initialisation.h"
 
+#include "ui/gui/options-dialog.h"
 #include "ui/gui/psppire.h"
 
 #include <gtk/gtk.h>
@@ -107,11 +108,9 @@ create_splash_window (void)
 {
   GtkWidget *sp = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  const gchar *filename = PKGDATADIR "/splash.png";
-  const char *relocated_filename = relocate (filename);
-  GtkWidget *l = gtk_image_new_from_file (relocated_filename);
-  if (filename != relocated_filename)
-    free (CONST_CAST (char *, relocated_filename));
+  char *splash = relocate_clone (PKGDATADIR"/splash.png");
+  GtkWidget *l = gtk_image_new_from_file (splash);
+  free (splash);
 
   gtk_container_add (GTK_CONTAINER (sp), l);
   gtk_window_set_type_hint (GTK_WINDOW (sp),
@@ -146,19 +145,19 @@ on_local_options (GApplication * application,
   {
     GVariant *b =
       g_variant_dict_lookup_value (options, "no-unique",
-				   G_VARIANT_TYPE_BOOLEAN);
+                                   G_VARIANT_TYPE_BOOLEAN);
     if (b)
       {
-	GApplicationFlags flags =  g_application_get_flags (application);
-	flags |= G_APPLICATION_NON_UNIQUE;
-	g_application_set_flags (application, flags);
-	g_variant_unref (b);
+        GApplicationFlags flags =  g_application_get_flags (application);
+        flags |= G_APPLICATION_NON_UNIQUE;
+        g_application_set_flags (application, flags);
+        g_variant_unref (b);
       }
   }
   {
     GVariant *b =
       g_variant_dict_lookup_value (options, "no-splash",
-				   G_VARIANT_TYPE_BOOLEAN);
+                                   G_VARIANT_TYPE_BOOLEAN);
     if (b)
       g_variant_unref (b);
     else
@@ -169,12 +168,18 @@ on_local_options (GApplication * application,
   return -1;
 }
 
+#ifdef __APPLE__
+#define  NON_FREE_OS "MacOS"
+#elif  _WIN32
+#define  NON_FREE_OS "Windows"
+#endif
+
 /* Use the imperitive mood for all entries in this table.
    Each entry should end with a period.   */
 static const char *tips[] =
   {
-#ifdef _WIN32
-   N_("PSPP runs best on free platforms such as GNU and GNU/Linux.  Windows is a non-free system.  As such, certain features might work sub-optimally.  For best results use a free system instead."),
+#ifdef NON_FREE_OS
+   N_("PSPP runs best on free platforms such as GNU and GNU/Linux.  " NON_FREE_OS " is a non-free system.  As such, certain features might work sub-optimally.  For best results use a free system instead."),
 #endif
    N_("Right click on variable lists to change between viewing the variables' names and their labels."),
    N_("Click \"Paste\" instead of \"OK\" when running procedures.  This allows you to edit your commands before running them and you have better control over your work."),
@@ -191,10 +196,8 @@ static const char *tips[] =
 static void
 user_tip (GApplication *app)
 {
-  PsppireConf *conf = psppire_conf_new ();
-
   gboolean show_tip = TRUE;
-  psppire_conf_get_boolean (conf, "startup", "show-user-tips", &show_tip);
+  psppire_conf_get_boolean ("startup", "show-user-tips", &show_tip);
 
   if (!show_tip)
     return;
@@ -274,11 +277,8 @@ user_tip (GApplication *app)
     }
 
   show_tip = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check));
-  psppire_conf_set_boolean (conf,
-                            "startup", "show-user-tips",
-                            show_tip);
-
-  g_object_unref (conf);
+  psppire_conf_set_boolean ("startup", "show-user-tips", show_tip);
+  psppire_conf_save ();
 
   gtk_widget_destroy (d);
 }
@@ -353,9 +353,9 @@ wait_for_splash (GApplication *app, GtkWindow *x)
       /* Remove the splash screen after SPLASH_DURATION milliseconds */
       gint64 elapsed_time = (g_get_monotonic_time () - start_time) / 1000;
       if (SPLASH_DURATION - elapsed_time <= 0)
-	destroy_splash (wsplash);
+        destroy_splash (wsplash);
       else
-	g_timeout_add (SPLASH_DURATION - elapsed_time, destroy_splash, wsplash);
+        g_timeout_add (SPLASH_DURATION - elapsed_time, destroy_splash, wsplash);
     }
 }
 
@@ -557,5 +557,6 @@ main (int argc, char *argv[])
   }
 
   g_object_set (G_OBJECT (app), "register-session", TRUE, NULL);
+
   return g_application_run (G_APPLICATION (app), argc, argv);
 }
