@@ -51,6 +51,8 @@ struct _PsppireDataEditor
 {
   GtkNotebook parent;
 
+  gboolean dispose_has_run;
+
   /* <private> */
   PsppireDataStore *data_store;
   PsppireDict *dict;
@@ -68,6 +70,7 @@ struct _PsppireDataEditor
   GtkWidget *datum_entry;      /* PsppireValueEntry for editing current cell. */
 
   gboolean split;              /* True if the sheets are in split view. */
+  gboolean use_value_labels;   /* True if labels instead of data are shown. */
 };
 
 struct _PsppireDataEditorClass
@@ -80,7 +83,7 @@ GType          psppire_data_editor_get_type        (void);
 GtkWidget*     psppire_data_editor_new             (PsppireDict *, PsppireDataStore *);
 void           psppire_data_editor_show_grid       (PsppireDataEditor *, gboolean);
 void           psppire_data_editor_set_font        (PsppireDataEditor *, PangoFontDescription *);
-void           psppire_data_editor_split_window    (PsppireDataEditor *, gboolean );
+void           psppire_data_editor_split_window    (PsppireDataEditor *, gboolean);
 
 void psppire_data_editor_goto_variable               (PsppireDataEditor *, gint dict_index);
 void psppire_data_editor_data_delete_variables       (PsppireDataEditor *de);
