@@ -34,22 +34,17 @@ static char *
 generate_syntax (const PsppireDialogAction *act)
 {
   PsppireDialogActionKmeans *km = PSPPIRE_DIALOG_ACTION_KMEANS (act);
-  gchar *text;
 
   GString *string = g_string_new ("QUICK CLUSTER ");
 
   psppire_var_view_append_names (PSPPIRE_VAR_VIEW (km->variables), 0, string);
 
   g_string_append_printf (string, "\n\t/CRITERIA=CLUSTERS(%d)",
-			  atoi (gtk_entry_get_text (GTK_ENTRY (km->entry))));
+                          atoi (gtk_entry_get_text (GTK_ENTRY (km->entry))));
 
   g_string_append (string, ".\n");
 
-  text = string->str;
-
-  g_string_free (string, FALSE);
-
-  return text;
+  return g_string_free_and_steal (string);
 }
 
 static gboolean
