@@ -50,7 +50,8 @@ GType role_enum_type;
 enum  {
   VARIABLE_CHANGED,
   VARIABLE_INSERTED,
-  VARIABLE_DELETED,
+  VARIABLES_DELETED,
+  VARIABLE_MOVED,
 
   WEIGHT_CHANGED,
   FILTER_CHANGED,
@@ -63,7 +64,7 @@ enum  {
 
 
 /* --- prototypes --- */
-static void psppire_dict_dispose	(GObject		*object);
+static void psppire_dict_dispose        (GObject                *object);
 
 static void dictionary_tree_model_init (GtkTreeModelIface *iface);
 
@@ -102,21 +103,21 @@ gi (GListModel *list, guint id)
       gtk_widget_set_tooltip_text (button, var_get_label (v));
 
       {
-	PangoContext *context = gtk_widget_create_pango_context (button);
-	PangoLayout *layout = pango_layout_new (context);
-	PangoRectangle rect;
+        PangoContext *context = gtk_widget_create_pango_context (button);
+        PangoLayout *layout = pango_layout_new (context);
+        PangoRectangle rect;
 
-	pango_layout_set_text (layout, "M", 1);
+        pango_layout_set_text (layout, "M", 1);
 
-	pango_layout_get_extents (layout, NULL, &rect);
+        pango_layout_get_extents (layout, NULL, &rect);
 
-	g_object_unref (G_OBJECT (layout));
-	g_object_unref (G_OBJECT (context));
+        g_object_unref (G_OBJECT (layout));
+        g_object_unref (G_OBJECT (context));
 
-	gtk_widget_set_size_request (button,
-				     (0.25 + var_get_display_width (v))
-				     * rect.width / PANGO_SCALE,
-				     -1);
+        gtk_widget_set_size_request (button,
+                                     (0.25 + var_get_display_width (v))
+                                     * rect.width / PANGO_SCALE,
+                                     -1);
       }
     }
 
@@ -141,10 +142,10 @@ static guint signals [n_SIGNALS];
 /* --- functions --- */
 
 G_DEFINE_TYPE_WITH_CODE (PsppireDict, psppire_dict, G_TYPE_OBJECT,
-			 G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
-						dictionary_tree_model_init)
-			 G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL,
-						ssw_init_iface))
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL,
+                                                dictionary_tree_model_init)
+                         G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL,
+                                                ssw_init_iface))
 
 static void
 psppire_dict_class_init (PsppireDictClass *class)
@@ -157,84 +158,95 @@ psppire_dict_class_init (PsppireDictClass *class)
 
   signals [RESIZE_ITEM] =
     g_signal_new ("resize-item",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_LAST,
-		  0,
-		  NULL, NULL,
-		  psppire_marshal_BOOLEAN__INT_INT,
-		  G_TYPE_BOOLEAN,
-		  2,
-		  G_TYPE_INT,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_LAST,
+                  0,
+                  NULL, NULL,
+                  psppire_marshal_BOOLEAN__INT_INT,
+                  G_TYPE_BOOLEAN,
+                  2,
+                  G_TYPE_INT,
+                  G_TYPE_INT);
 
   signals [VARIABLE_CHANGED] =
     g_signal_new ("variable-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  psppire_marshal_VOID__INT_UINT_POINTER,
-		  G_TYPE_NONE,
-		  3,
-		  G_TYPE_INT,
-		  G_TYPE_UINT,
-		  G_TYPE_POINTER);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  psppire_marshal_VOID__INT_UINT_POINTER,
+                  G_TYPE_NONE,
+                  3,
+                  G_TYPE_INT,
+                  G_TYPE_UINT,
+                  G_TYPE_POINTER);
 
   signals [VARIABLE_INSERTED] =
     g_signal_new ("variable-inserted",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__INT,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__INT,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_INT);
 
-  signals [VARIABLE_DELETED] =
-    g_signal_new ("variable-deleted",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  psppire_marshal_VOID__POINTER_INT_INT,
-		  G_TYPE_NONE,
-		  3,
-		  G_TYPE_POINTER,
-		  G_TYPE_INT,
-		  G_TYPE_INT);
+  signals [VARIABLES_DELETED] =
+    g_signal_new ("variables-deleted",
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  psppire_marshal_VOID__INT_UINT,
+                  G_TYPE_NONE,
+                  2,
+                  G_TYPE_INT,
+                  G_TYPE_UINT);
+
+  signals [VARIABLE_MOVED] =
+    g_signal_new ("variable-moved",
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  psppire_marshal_VOID__INT_INT,
+                  G_TYPE_NONE,
+                  2,
+                  G_TYPE_INT,
+                  G_TYPE_INT);
 
   signals [WEIGHT_CHANGED] =
     g_signal_new ("weight-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__INT,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__INT,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_INT);
 
   signals [FILTER_CHANGED] =
     g_signal_new ("filter-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__INT,
-		  G_TYPE_NONE,
-		  1,
-		  G_TYPE_INT);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__INT,
+                  G_TYPE_NONE,
+                  1,
+                  G_TYPE_INT);
 
   signals [SPLIT_CHANGED] =
     g_signal_new ("split-changed",
-		  G_TYPE_FROM_CLASS (class),
-		  G_SIGNAL_RUN_FIRST,
-		  0,
-		  NULL, NULL,
-		  g_cclosure_marshal_VOID__VOID,
-		  G_TYPE_NONE,
-		  0);
+                  G_TYPE_FROM_CLASS (class),
+                  G_SIGNAL_RUN_FIRST,
+                  0,
+                  NULL, NULL,
+                  g_cclosure_marshal_VOID__VOID,
+                  G_TYPE_NONE,
+                  0);
 }
 
 static void
@@ -256,7 +268,7 @@ psppire_dict_dispose (GObject *object)
 /* Pass on callbacks from src/data/dictionary, as
    signals in the Gtk library */
 static void
-addcb (struct dictionary *d, int idx, void *pd)
+var_added_callback (struct dictionary *d, int idx, void *pd)
 {
   PsppireDict *dict = PSPPIRE_DICT (pd);
 
@@ -268,16 +280,20 @@ addcb (struct dictionary *d, int idx, void *pd)
 }
 
 static void
-delcb (struct dictionary *d, const struct variable *var,
-       int dict_idx, int case_idx, void *pd)
+vars_deleted_callback (struct dictionary *d, int dict_idx, unsigned int n, void *pd)
 {
-  g_signal_emit (pd, signals [VARIABLE_DELETED], 0,
-                 var, dict_idx, case_idx);
+  g_signal_emit (pd, signals [VARIABLES_DELETED], 0, dict_idx, n);
   g_signal_emit_by_name (pd, "items-changed",  dict_idx, 1, 0);
 }
 
 static void
-mutcb (struct dictionary *d, int idx, unsigned int what, const struct variable *oldvar, void *pd)
+var_moved_callback (struct dictionary *d, int new_dict_index, int old_dict_index, void *pd)
+{
+  g_signal_emit (pd, signals [VARIABLE_MOVED], 0, new_dict_index, old_dict_index);
+}
+
+static void
+var_changed_callback (struct dictionary *d, int idx, unsigned int what, const struct variable *oldvar, void *pd)
 {
   g_signal_emit (pd, signals [VARIABLE_CHANGED], 0, idx, what, oldvar);
   g_signal_emit_by_name (pd, "items-changed", idx, 1, 1);
@@ -303,12 +319,13 @@ split_changed_callback (struct dictionary *d, void *pd)
 
 static const struct dict_callbacks gui_callbacks =
   {
-    addcb,
-    delcb,
-    mutcb,
-    weight_changed_callback,
-    filter_changed_callback,
-    split_changed_callback
+    .var_added = var_added_callback,
+    .vars_deleted = vars_deleted_callback,
+    .var_moved = var_moved_callback,
+    .var_changed = var_changed_callback,
+    .weight_changed = weight_changed_callback,
+    .filter_changed = filter_changed_callback,
+    .split_changed = split_changed_callback
   };
 
 static void
@@ -454,7 +471,7 @@ psppire_dict_set_name (PsppireDict* d, gint idx, const gchar *name)
   g_assert (d);
   g_assert (PSPPIRE_IS_DICT (d));
 
-  if (! dict_id_is_valid (d->dict, name, false))
+  if (! dict_id_is_valid (d->dict, name, DC_ORDINARY))
     return FALSE;
 
   if (idx < dict_get_n_vars (d->dict))
@@ -501,17 +518,6 @@ psppire_dict_get_n_vars (const PsppireDict *d)
 }
 
 
-/* Return the number of `union value's in the dictionary */
-size_t
-psppire_dict_get_n_values (const PsppireDict *d)
-{
-  g_return_val_if_fail (d, -1);
-  g_return_val_if_fail (d->dict, -1);
-
-  return dict_get_next_value_idx (d->dict);
-}
-
-
 /* Returns the prototype for the cases that match the dictionary */
 const struct caseproto *
 psppire_dict_get_proto (const PsppireDict *d)
@@ -550,33 +556,15 @@ psppire_dict_clear (PsppireDict *d)
 
 /* Return true if NAME would be a valid name of a variable to add to the
    dictionary.  False otherwise.
-   If REPORT is true, then invalid names will be reported as such as errors
 */
 gboolean
 psppire_dict_check_name (const PsppireDict *dict,
-			 const gchar *name, gboolean report)
+                         const gchar *name)
 {
-  if (! dict_id_is_valid (dict->dict, name, report))
-    return FALSE;
-
-  if (psppire_dict_lookup_var (dict, name))
-    {
-      if (report)
-	msg (ME, _("Duplicate variable name."));
-      return FALSE;
-    }
-
-  return TRUE;
+  return (dict_id_is_valid (dict->dict, name, DC_ORDINARY)
+          && !psppire_dict_lookup_var (dict, name));
 }
 
-
-gint
-psppire_dict_get_next_value_idx (const PsppireDict *dict)
-{
-  return dict_get_next_value_idx (dict->dict);
-}
-
-
 /* Tree Model Stuff */
 
 static GtkTreeModelFlags tree_model_get_flags (GtkTreeModel *model);
@@ -586,32 +574,32 @@ static gint tree_model_n_columns (GtkTreeModel *model);
 static GType tree_model_column_type (GtkTreeModel *model, gint index);
 
 static gboolean tree_model_get_iter (GtkTreeModel *model, GtkTreeIter *iter,
-				     GtkTreePath *path);
+                                     GtkTreePath *path);
 
 static gboolean tree_model_iter_next (GtkTreeModel *model, GtkTreeIter *iter);
 
 static GtkTreePath * tree_model_get_path (GtkTreeModel *model,
-					  GtkTreeIter *iter);
+                                          GtkTreeIter *iter);
 
 static void tree_model_get_value (GtkTreeModel *model, GtkTreeIter *iter,
-				  gint column, GValue *value);
+                                  gint column, GValue *value);
 
 static gboolean tree_model_nth_child (GtkTreeModel *model, GtkTreeIter *iter,
-				      GtkTreeIter *parent, gint n);
+                                      GtkTreeIter *parent, gint n);
 
 static gint tree_model_n_children (GtkTreeModel *tree_model,
-				   GtkTreeIter  *iter);
+                                   GtkTreeIter  *iter);
 
 static gboolean tree_model_iter_children (GtkTreeModel *,
-					  GtkTreeIter *,
-					  GtkTreeIter *);
+                                          GtkTreeIter *,
+                                          GtkTreeIter *);
 
 static gboolean tree_model_iter_parent (GtkTreeModel *tree_model,
-					GtkTreeIter *iter,
-					GtkTreeIter *child);
+                                        GtkTreeIter *iter,
+                                        GtkTreeIter *child);
 
 static gboolean tree_model_iter_has_child  (GtkTreeModel *tree_model,
-					    GtkTreeIter  *iter);
+                                            GtkTreeIter  *iter);
 
 static void
 dictionary_tree_model_init (GtkTreeModelIface *iface)
@@ -633,15 +621,15 @@ dictionary_tree_model_init (GtkTreeModelIface *iface)
 
 static gboolean
 tree_model_iter_has_child  (GtkTreeModel *tree_model,
-			    GtkTreeIter  *iter)
+                            GtkTreeIter  *iter)
 {
   return FALSE;
 }
 
 static gboolean
 tree_model_iter_parent (GtkTreeModel *tree_model,
-		        GtkTreeIter *iter,
-		        GtkTreeIter *child)
+                        GtkTreeIter *iter,
+                        GtkTreeIter *child)
 {
   return TRUE;
 }
@@ -781,11 +769,11 @@ tree_model_get_path (GtkTreeModel *model, GtkTreeIter *iter)
   return path;
 }
 
-const struct fmt_spec *var_get_write_format (const struct variable *);
+struct fmt_spec var_get_write_format (const struct variable *);
 
 static void
 tree_model_get_value (GtkTreeModel *model, GtkTreeIter *iter,
-		      gint column, GValue *value)
+                      gint column, GValue *value)
 {
   struct variable *var;
   PsppireDict *dict = PSPPIRE_DICT (model);
@@ -794,7 +782,7 @@ tree_model_get_value (GtkTreeModel *model, GtkTreeIter *iter,
 
   var = iter->user_data;
 
-  const struct fmt_spec *fs = var_get_write_format (var);
+  struct fmt_spec fs = var_get_write_format (var);
 
   switch (column)
     {
@@ -804,11 +792,11 @@ tree_model_get_value (GtkTreeModel *model, GtkTreeIter *iter,
       break;
     case DICT_TVM_COL_WIDTH:
       g_value_init (value, G_TYPE_INT);
-      g_value_set_int (value, fs->w);
+      g_value_set_int (value, fs.w);
       break;
     case DICT_TVM_COL_DECIMAL:
       g_value_init (value, G_TYPE_INT);
-      g_value_set_int (value, fs->d);
+      g_value_set_int (value, fs.d);
       break;
     case DICT_TVM_COL_LABEL:
       g_value_init (value, G_TYPE_STRING);
@@ -843,15 +831,15 @@ tree_model_get_value (GtkTreeModel *model, GtkTreeIter *iter,
 
 static gboolean
 tree_model_iter_children (GtkTreeModel *tree_model,
-			  GtkTreeIter *iter,
-			  GtkTreeIter *parent)
+                          GtkTreeIter *iter,
+                          GtkTreeIter *parent)
 {
   return FALSE;
 }
 
 static gint
 tree_model_n_children (GtkTreeModel *model,
-		       GtkTreeIter  *iter)
+                       GtkTreeIter  *iter)
 {
   PsppireDict *dict = PSPPIRE_DICT (model);
 
@@ -863,7 +851,7 @@ tree_model_n_children (GtkTreeModel *model,
 
 static gboolean
 tree_model_nth_child (GtkTreeModel *model, GtkTreeIter *iter,
-		      GtkTreeIter *parent, gint n)
+                      GtkTreeIter *parent, gint n)
 {
   PsppireDict *dict;
 
@@ -889,9 +877,9 @@ tree_model_nth_child (GtkTreeModel *model, GtkTreeIter *iter,
 
 gboolean
 psppire_dict_rename_var (PsppireDict *dict, struct variable *v,
-			 const gchar *name)
+                         const gchar *name)
 {
-  if (! dict_id_is_valid (dict->dict, name, false))
+  if (! dict_id_is_valid (dict->dict, name, DC_ORDINARY))
     return FALSE;
 
   /* Make sure no other variable has this name */
