@@ -22,6 +22,7 @@
 
 #include <gtksourceview/gtksource.h>
 
+#include "language/lexer/command-segmenter.h"
 #include "language/lexer/lexer.h"
 #include "libpspp/encoding-guesser.h"
 #include "libpspp/i18n.h"
@@ -35,6 +36,7 @@
 #include "ui/gui/psppire-lex-reader.h"
 #include "ui/gui/psppire-syntax-window.h"
 #include "ui/gui/psppire.h"
+#include "ui/gui/psppire-search-dialog.h"
 #include "ui/gui/windows-menu.h"
 
 #include "gl/localcharset.h"
@@ -123,8 +125,6 @@ psppire_syntax_window_dispose (GObject *obj)
   if (sw->dispose_has_run)
     return;
 
-  g_object_unref (sw->search_text_buffer);
-
   g_free (sw->encoding);
   sw->encoding = NULL;
 
@@ -157,9 +157,11 @@ psppire_syntax_window_class_init (PsppireSyntaxWindowClass *class)
   gchar **new_paths = g_strdupv ((gchar **)existing_paths);
   int n = g_strv_length ((gchar **) existing_paths);
 
+  char *pkg_data_dir = relocate_clone (PKGDATADIR);
   new_paths = g_realloc (new_paths, (n + 2) * sizeof (*new_paths));
-  new_paths[n] = g_strdup (relocate (PKGDATADIR));
+  new_paths[n] = g_strdup (pkg_data_dir);
   new_paths[n+1] = NULL;
+  free (pkg_data_dir);
 
   lm = gtk_source_language_manager_new ();
   gtk_source_language_manager_set_search_path (lm, new_paths);
@@ -177,8 +179,8 @@ psppire_syntax_window_class_init (PsppireSyntaxWindowClass *class)
     null_if_empty_param ("encoding",
                          "Character encoding",
                          "IANA character encoding in this syntax file",
-			 NULL,
-			 G_PARAM_CONSTRUCT | G_PARAM_READWRITE);
+                         NULL,
+                         G_PARAM_CONSTRUCT | G_PARAM_READWRITE);
 
   parent_class = g_type_class_peek_parent (class);
 
@@ -194,7 +196,7 @@ psppire_syntax_window_class_init (PsppireSyntaxWindowClass *class)
 
 static void
 editor_execute_syntax (const PsppireSyntaxWindow *sw, GtkTextIter start,
-		       GtkTextIter stop)
+                       GtkTextIter stop)
 {
   PsppireWindow *win = PSPPIRE_WINDOW (sw);
   struct lex_reader *reader = lex_reader_for_gtk_text_buffer (
@@ -208,7 +210,9 @@ editor_execute_syntax (const PsppireSyntaxWindow *sw, GtkTextIter start,
 
   execute_syntax (psppire_default_data_window (), reader);
 }
+
 
+
 /* Delete the currently selected text */
 static void
 on_edit_delete (PsppireSyntaxWindow *sw)
@@ -220,84 +224,65 @@ on_edit_delete (PsppireSyntaxWindow *sw)
     gtk_text_buffer_delete (buffer, &begin, &end);
 }
 
-/* Create and run a dialog to collect the search string.
-   In future this might be expanded to include options, for example
-   backward searching, case sensitivity etc.  */
-static const char *
-get_search_text (PsppireSyntaxWindow *parent)
+typedef gboolean search_function (GtkSourceSearchContext *search,
+                                  const GtkTextIter *iter,
+                                  GtkTextIter *match_start,
+                                  GtkTextIter *match_end,
+                                   gboolean *has_wrapped_around);
+
+
+/* This function is called when the user clicks the Find button */
+static void on_find (PsppireSyntaxWindow *sw, gboolean backwards, gpointer data, gpointer junk)
 {
-  const char *search_text = NULL;
-  GtkDialogFlags flags = GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL;
-  GtkWidget *dialog = gtk_dialog_new_with_buttons (_("Text Search"),
-                                                   GTK_WINDOW (parent),
-                                                   flags,
-                                                   _("_OK"),
-                                                   GTK_RESPONSE_OK,
-                                                   _("_Cancel"),
-                                                   GTK_RESPONSE_CANCEL,
-                                                   NULL);
+  PsppireSearchDialog *dialog = PSPPIRE_SEARCH_DIALOG (data);
 
-  GtkWidget *content_area =
-    gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+  const char *search_text = gtk_entry_get_text (GTK_ENTRY (dialog->entry));
+  if (search_text == NULL)
+    return;
 
-  GtkWidget *box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
-  GtkWidget *label = gtk_label_new (_("Text to search for:"));
-  GtkWidget *entry = gtk_entry_new_with_buffer (parent->search_text_buffer);
+  GtkTextBuffer *buffer = GTK_TEXT_BUFFER (sw->buffer);
+  GtkTextIter begin;
+  GtkTextIter loc;
 
-  /* Add the label, and show everything we have added.  */
-  gtk_container_add (GTK_CONTAINER (content_area), box);
-  gtk_container_add (GTK_CONTAINER (box), label);
-  gtk_container_add (GTK_CONTAINER (box), entry);
-  gtk_widget_show_all (content_area);
+  GtkTextMark *mark = gtk_text_buffer_get_insert (buffer);
 
-  int result = gtk_dialog_run (GTK_DIALOG (dialog));
-  switch (result)
+  GtkSourceSearchSettings *sss = gtk_source_search_context_get_settings (sw->search_context);
+  gtk_source_search_settings_set_search_text (sss, search_text);
+  gtk_source_search_settings_set_case_sensitive (sss,
+                                                 !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->ignore_case)));
+
+  gtk_source_search_settings_set_at_word_boundaries (sss,
+                                                     gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->whole)));
+
+  gtk_source_search_settings_set_wrap_around (sss,
+                                              gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->wrap)));
+
+  search_function *func = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->forward))
+                                                        ? gtk_source_search_context_forward
+                                                        : gtk_source_search_context_backward;
+
+  gtk_text_buffer_get_iter_at_mark (buffer, &begin, mark);
+  gtk_text_iter_forward_char (&begin);
+  if (func (sw->search_context, &begin, &loc, NULL, NULL))
     {
-    case GTK_RESPONSE_OK:
-      search_text = gtk_entry_get_text (GTK_ENTRY (entry));
-      break;
-    default:
-      search_text = NULL;
-    };
-
-  gtk_widget_destroy (dialog);
-  return search_text;
+      gtk_text_buffer_place_cursor (buffer, &loc);
+    }
 }
 
-
 /* What to do when the Find menuitem is called.  */
 static void
 on_edit_find (PsppireSyntaxWindow *sw)
 {
-  GtkTextBuffer *buffer = GTK_TEXT_BUFFER (sw->buffer);
-  GtkTextIter begin;
-  GtkTextIter loc;
-  const char *target = get_search_text (sw);
+  GtkWidget *ww = psppire_search_dialog_new ();
+  gtk_window_set_transient_for (GTK_WINDOW (ww), GTK_WINDOW (sw));
 
-  if (target == NULL)
-    return;
+  g_signal_connect_swapped (ww, "find", G_CALLBACK (on_find), sw);
 
-  /* This is a wrap-around search.  So start searching one
-     character after the current char.  */
-  GtkTextMark *mark = gtk_text_buffer_get_insert (buffer);
-  gtk_text_buffer_get_iter_at_mark (buffer, &begin, mark);
-  gtk_text_iter_forward_char (&begin);
-  if (gtk_text_iter_forward_search (&begin, target, 0,
-                                    &loc, 0, 0))
-    {
-      gtk_text_buffer_place_cursor (buffer, &loc);
-    }
-  else
-    {
-      /* If not found, then continue the search from the top
-         of the buffer.  */
-      gtk_text_buffer_get_start_iter (buffer, &begin);
-      if (gtk_text_iter_forward_search (&begin, target, 0,
-                                        &loc, 0, 0))
-        {
-          gtk_text_buffer_place_cursor (buffer, &loc);
-        }
-    }
+  sw->search_context = gtk_source_search_context_new (sw->buffer, NULL);
+
+  psppire_dialog_run (PSPPIRE_DIALOG (ww));
+
+  g_object_unref (sw->search_context);
 }
 
 
@@ -321,22 +306,22 @@ selection_changed (PsppireSyntaxWindow *sw)
 /* The callback which runs when something request clipboard data */
 static void
 clipboard_get_cb (GtkClipboard     *clipboard,
-		  GtkSelectionData *selection_data,
-		  guint             info,
-		  gpointer          data)
+                  GtkSelectionData *selection_data,
+                  guint             info,
+                  gpointer          data)
 {
   PsppireSyntaxWindow *sw = data;
   g_assert (info == SELECT_FMT_TEXT);
 
   gtk_selection_data_set (selection_data, gtk_selection_data_get_target (selection_data),
-			  8,
-			  (const guchar *) sw->cliptext, strlen (sw->cliptext));
+                          8,
+                          (const guchar *) sw->cliptext, strlen (sw->cliptext));
 
 }
 
 static void
 clipboard_clear_cb (GtkClipboard *clipboard,
-		    gpointer data)
+                    gpointer data)
 {
   PsppireSyntaxWindow *sw = data;
   g_free (sw->cliptext);
@@ -381,9 +366,9 @@ set_clip (PsppireSyntaxWindow *sw, GtkTextIter *begin, GtkTextIter *end)
     gtk_widget_get_clipboard (GTK_WIDGET (sw), GDK_SELECTION_CLIPBOARD);
 
   if (!gtk_clipboard_set_with_owner (clipboard, targets,
-				     G_N_ELEMENTS (targets),
-				     clipboard_get_cb, clipboard_clear_cb,
-				     G_OBJECT (sw)))
+                                     G_N_ELEMENTS (targets),
+                                     clipboard_get_cb, clipboard_clear_cb,
+                                     G_OBJECT (sw)))
     clipboard_clear_cb (clipboard, sw);
 
   return TRUE;
@@ -431,10 +416,10 @@ set_paste_sensitivity (GtkClipboard *clip, GdkEventOwnerChange *event, gpointer
     {
       GdkAtom atom = gdk_atom_intern (targets[i].target, TRUE);
       if (gtk_clipboard_wait_is_target_available (clip, atom))
-	{
-	  compatible_target = TRUE;
-	  break;
-	}
+        {
+          compatible_target = TRUE;
+          break;
+        }
     }
 
   g_object_set (sw->edit_paste, "enabled", compatible_target, NULL);
@@ -455,70 +440,137 @@ on_run_all (PsppireSyntaxWindow *se)
   editor_execute_syntax (se, begin, end);
 }
 
-/* Parse and execute the currently selected text */
+static bool
+overlaps (int a[2], int b[2])
+{
+  return (b[0] <= a[0] && a[0] < b[1]) || (a[0] <= b[0] && b[0] < a[1]);
+}
+
+/* Parse and execute the commands that overlap [START, END). */
+static void
+run_commands (PsppireSyntaxWindow *se, GtkTextIter start, GtkTextIter end)
+{
+  GtkTextBuffer *buf = GTK_TEXT_BUFFER (se->buffer);
+
+  /* Convert the iterator range into a line number range.  Both ranges are
+     half-open (they exclude the end), but it's OK for them to be empty. */
+  int in_lines[2] = {
+    gtk_text_iter_get_line (&start),
+    gtk_text_iter_get_line (&end),
+  };
+  if (in_lines[0] == in_lines[1] || gtk_text_iter_get_line_index (&end) > 0)
+    in_lines[1]++;
+
+  /* These are the lines that we're going to run.  */
+  int run_lines[2] = { -1, -1 };
+
+  /* Iterate through all the text in the buffer until we find a command that
+     spans the line we're on. */
+  struct command_segmenter *cs = command_segmenter_create (se->syntax_mode);
+  GtkTextIter begin;
+  gtk_text_buffer_get_start_iter (buf, &begin);
+  while (!gtk_text_iter_is_end (&begin))
+    {
+      GtkTextIter next = begin;
+      gtk_text_iter_forward_line (&next);
+
+      gchar *text = gtk_text_iter_get_text (&begin, &next);
+      command_segmenter_push (cs, text, strlen (text));
+      g_free (text);
+
+      if (gtk_text_iter_is_end (&next))
+        command_segmenter_eof (cs);
+
+      int cmd_lines[2];
+      while (command_segmenter_get (cs, cmd_lines))
+        {
+          if (overlaps (cmd_lines, in_lines))
+            {
+              /* This command's lines overlap with the lines we want to run.
+                 If we don't have any lines yet, take this command's lines;
+                 otherwise, extend the lines we have with this command's
+                 lines. */
+              if (run_lines[0] == -1)
+                {
+                  run_lines[0] = cmd_lines[0];
+                  run_lines[1] = cmd_lines[1];
+                }
+              else
+                run_lines[1] = cmd_lines[1];
+            }
+          else if (cmd_lines[0] >= in_lines[1])
+            {
+              /* We're moved past the lines that could possibly overlap with
+                 those that we want to run.
+
+                 If we don't have anything to run, we need to make some guess.
+                 If we were just given a single position, then probably it
+                 makes sense to run the next command.  Otherwise, we were given
+                 a nonempty selection that didn't contain any commands, and it
+                 seems reasonable to not run any. */
+              if (run_lines[0] == -1 && gtk_text_iter_equal (&start, &end))
+                {
+                  run_lines[0] = cmd_lines[0];
+                  run_lines[1] = cmd_lines[1];
+                }
+              break;
+            }
+        }
+
+      begin = next;
+    }
+  command_segmenter_destroy (cs);
+
+  if (run_lines[0] != -1)
+    {
+      GtkTextIter begin, end;
+      gtk_text_buffer_get_iter_at_line (buf, &begin, run_lines[0]);
+      gtk_text_buffer_get_iter_at_line (buf, &end, run_lines[1]);
+
+      editor_execute_syntax (se, begin, end);
+    }
+}
+
+static GtkTextIter
+get_iter_for_cursor (PsppireSyntaxWindow *se)
+{
+  GtkTextBuffer *buf = GTK_TEXT_BUFFER (se->buffer);
+  GtkTextIter iter;
+  gtk_text_buffer_get_iter_at_mark (
+    buf, &iter, gtk_text_buffer_get_insert (buf));
+  return iter;
+}
+
+/* Parse and execute the currently selected syntax, if there is any, and
+   otherwise the command that the cursor is in. */
 static void
 on_run_selection (PsppireSyntaxWindow *se)
 {
-  GtkTextIter begin, end;
+  GtkTextBuffer *buf = GTK_TEXT_BUFFER (se->buffer);
 
-  if (gtk_text_buffer_get_selection_bounds (GTK_TEXT_BUFFER (se->buffer), &begin, &end))
-    editor_execute_syntax (se, begin, end);
+  GtkTextIter begin, end;
+  if (gtk_text_buffer_get_selection_bounds (buf, &begin, &end))
+    run_commands (se, begin, end);
+  else
+    {
+      GtkTextIter iter = get_iter_for_cursor (se);
+      run_commands (se, iter, iter);
+    }
 }
 
 
-/* Parse and execute the from the current line, to the end of the
-   buffer */
+/* Parse and execute the syntax from the current line, to the end of the
+   buffer. */
 static void
 on_run_to_end (PsppireSyntaxWindow *se)
 {
-  GtkTextIter begin, end;
-  GtkTextIter here;
-  gint line;
+  GtkTextBuffer *buf = GTK_TEXT_BUFFER (se->buffer);
+  GtkTextIter end;
+  gtk_text_buffer_get_end_iter (buf, &end);
 
-  /* Get the current line */
-  gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (se->buffer),
-				    &here,
-				    gtk_text_buffer_get_insert (GTK_TEXT_BUFFER (se->buffer))
-				);
-
-  line = gtk_text_iter_get_line (&here) ;
-
-  /* Now set begin and end to the start of this line, and end of buffer
-     respectively */
-  gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (se->buffer), &begin, line);
-  gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (se->buffer), &end, -1);
-
-  editor_execute_syntax (se, begin, end);
+  run_commands (se, get_iter_for_cursor (se), end);
 }
 
-
-
-/* Parse and execute the current line */
-static void
-on_run_current_line (PsppireSyntaxWindow *se)
-{
-  GtkTextIter begin, end;
-  GtkTextIter here;
-  gint line;
-
-  /* Get the current line */
-  gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (se->buffer),
-				    &here,
-				    gtk_text_buffer_get_insert (GTK_TEXT_BUFFER (se->buffer))
-				);
-
-  line = gtk_text_iter_get_line (&here) ;
-
-  /* Now set begin and end to the start of this line, and start of
-     following line respectively */
-  gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (se->buffer), &begin, line);
-  gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (se->buffer), &end, line + 1);
-
-  editor_execute_syntax (se, begin, end);
-}
-
-
-
 static void
 on_syntax (GAction *action, GVariant *param, PsppireSyntaxWindow *sw)
 {
@@ -559,8 +611,8 @@ append_suffix (const gchar *filename)
 */
 static gboolean
 save_editor_to_file (PsppireSyntaxWindow *se,
-		     const gchar *filename,
-		     GError **err)
+                     const gchar *filename,
+                     GError **err)
 {
   GtkTextBuffer *buffer = GTK_TEXT_BUFFER (se->buffer);
   struct substring text_locale;
@@ -612,11 +664,11 @@ syntax_pick_filename (PsppireWindow *window)
 
   GtkWidget *dialog =
     gtk_file_chooser_dialog_new (_("Save Syntax"),
-				 GTK_WINDOW (se),
-				 GTK_FILE_CHOOSER_ACTION_SAVE,
-				 _("Cancel"), GTK_RESPONSE_CANCEL,
-				 _("Save"),   GTK_RESPONSE_ACCEPT,
-				 NULL);
+                                 GTK_WINDOW (se),
+                                 GTK_FILE_CHOOSER_ACTION_SAVE,
+                                 _("Cancel"), GTK_RESPONSE_CANCEL,
+                                 _("Save"),   GTK_RESPONSE_ACCEPT,
+                                 NULL);
 
   g_object_set (dialog, "local-only", FALSE, NULL);
 
@@ -632,7 +684,7 @@ syntax_pick_filename (PsppireWindow *window)
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
 
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog),
-						  TRUE);
+                                                  TRUE);
 
   default_encoding = se->encoding != NULL ? se->encoding : locale_charset ();
   gtk_file_chooser_set_extra_widget (
@@ -771,16 +823,16 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
   gtk_text_view_set_buffer (GTK_TEXT_VIEW (text_view), GTK_TEXT_BUFFER (window->buffer));
 
   g_object_set (window->buffer,
-		"highlight-matching-brackets", TRUE,
-		NULL);
+                "highlight-matching-brackets", TRUE,
+                NULL);
 
   g_object_set (text_view,
-		"show-line-numbers", TRUE,
-		"show-line-marks", TRUE,
-		"auto-indent", TRUE,
-		"indent-width", 4,
-		"highlight-current-line", TRUE,
-		NULL);
+                "show-line-numbers", TRUE,
+                "show-line-marks", TRUE,
+                "auto-indent", TRUE,
+                "indent-width", 4,
+                "highlight-current-line", TRUE,
+                NULL);
 
   window->encoding = NULL;
   window->syntax_mode = SEG_MODE_AUTO;
@@ -788,7 +840,7 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
   window->cliptext = NULL;
   window->dispose_has_run = FALSE;
 
-  window->search_text_buffer = gtk_entry_buffer_new (NULL, -1);
+  window->search_context = NULL;
 
   window->edit_delete = g_simple_action_new ("delete", NULL);
   g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (window->edit_delete));
@@ -811,39 +863,39 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
   window->text_context = gtk_statusbar_get_context_id (GTK_STATUSBAR (window->sb), "Text Context");
 
   g_signal_connect (window->buffer, "changed",
-		    G_CALLBACK (on_text_changed), window);
+                    G_CALLBACK (on_text_changed), window);
 
   g_signal_connect (window->buffer, "modified-changed",
-		    G_CALLBACK (on_modified_changed), window);
+                    G_CALLBACK (on_modified_changed), window);
 
 
   {
     GSimpleAction *print = g_simple_action_new ("print", NULL);
 
     g_signal_connect_swapped (print, "activate",
-			      G_CALLBACK (psppire_syntax_window_print), window);
+                              G_CALLBACK (psppire_syntax_window_print), window);
 
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (print));
   }
 
   g_signal_connect_swapped (window->undo_menuitem,
-			    "activate",
-			    G_CALLBACK (undo_last_edit),
-			    window);
+                            "activate",
+                            G_CALLBACK (undo_last_edit),
+                            window);
 
   g_signal_connect_swapped (window->redo_menuitem,
-			    "activate",
+                            "activate",
                             G_CALLBACK (redo_last_edit),
-			    window);
+                            window);
 
   undo_redo_update (window);
 
 
   window->sel_handler = g_signal_connect_swapped (clip_primary, "owner-change",
-						   G_CALLBACK (selection_changed), window);
+                                                   G_CALLBACK (selection_changed), window);
 
   window->ps_handler = g_signal_connect (clip_selection, "owner-change",
-					  G_CALLBACK (set_paste_sensitivity), window);
+                                          G_CALLBACK (set_paste_sensitivity), window);
 
   gtk_container_add (GTK_CONTAINER (window), box);
 
@@ -865,9 +917,9 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (open));
 
     g_signal_connect_swapped (open,
-			      "activate",
-			      G_CALLBACK (psppire_window_open),
-			      window);
+                              "activate",
+                              G_CALLBACK (psppire_window_open),
+                              window);
   }
 
   {
@@ -876,14 +928,14 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (save));
 
     g_signal_connect_swapped (save,
-			      "activate",
-			      G_CALLBACK (psppire_window_save),
-			      window);
+                              "activate",
+                              G_CALLBACK (psppire_window_save),
+                              window);
 
     const gchar *accels[2] = { "<Primary>S", NULL};
     gtk_application_set_accels_for_action (app,
-					   "win.save",
-					   accels);
+                                           "win.save",
+                                           accels);
 
   }
 
@@ -893,99 +945,90 @@ psppire_syntax_window_init (PsppireSyntaxWindow *window)
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (save_as));
 
     g_signal_connect_swapped (save_as,
-			      "activate",
-			      G_CALLBACK (psppire_window_save_as),
-			      window);
+                              "activate",
+                              G_CALLBACK (psppire_window_save_as),
+                              window);
 
 
     const gchar *accels[2] = { "<Shift><Primary>S", NULL};
     gtk_application_set_accels_for_action (app,
-					   "win.save_as",
-					   accels);
+                                           "win.save_as",
+                                           accels);
 
 
   }
 
 
   g_signal_connect_swapped (window->edit_delete,
-		    "activate",
-		    G_CALLBACK (on_edit_delete),
-		    window);
+                    "activate",
+                    G_CALLBACK (on_edit_delete),
+                    window);
 
   g_signal_connect_swapped (window->edit_copy,
-		    "activate",
-		    G_CALLBACK (on_edit_copy),
-		    window);
+                    "activate",
+                    G_CALLBACK (on_edit_copy),
+                    window);
 
   g_signal_connect_swapped (window->edit_cut,
-		    "activate",
-		    G_CALLBACK (on_edit_cut),
-		    window);
+                    "activate",
+                    G_CALLBACK (on_edit_cut),
+                    window);
 
   g_signal_connect_swapped (window->edit_paste,
-		    "activate",
-		    G_CALLBACK (on_edit_paste),
-		    window);
+                    "activate",
+                    G_CALLBACK (on_edit_paste),
+                    window);
 
   g_signal_connect_swapped (window->edit_find,
-		    "activate",
-		    G_CALLBACK (on_edit_find),
-		    window);
+                    "activate",
+                    G_CALLBACK (on_edit_find),
+                    window);
 
   {
     GSimpleAction *run_all = g_simple_action_new ("run-all", NULL);
 
     g_signal_connect_swapped (run_all, "activate",
-			      G_CALLBACK (on_run_all), window);
+                              G_CALLBACK (on_run_all), window);
 
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (run_all));
   }
 
-  {
-    GSimpleAction *run_current_line = g_simple_action_new ("run-current-line", NULL);
-
-    g_signal_connect_swapped (run_current_line, "activate",
-			      G_CALLBACK (on_run_current_line), window);
-
-    g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (run_current_line));
-
-    GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
-    const gchar *accels[2] = { "<Primary>R", NULL};
-    gtk_application_set_accels_for_action (app,
-					   "win.run-current-line",
-					   accels);
-  }
-
   {
     GSimpleAction *run_selection = g_simple_action_new ("run-selection", NULL);
 
     g_signal_connect_swapped (run_selection, "activate",
-			      G_CALLBACK (on_run_selection), window);
+                              G_CALLBACK (on_run_selection), window);
 
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (run_selection));
+
+    GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
+    const gchar *accels[2] = { "<Primary>R", NULL};
+    gtk_application_set_accels_for_action (app,
+                                           "win.run-selection",
+                                           accels);
   }
 
   {
     GSimpleAction *run_to_end = g_simple_action_new ("run-to-end", NULL);
 
     g_signal_connect_swapped (run_to_end, "activate",
-			      G_CALLBACK (on_run_to_end), window);
+                              G_CALLBACK (on_run_to_end), window);
 
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (run_to_end));
   }
 
   {
     GSimpleAction *act_syntax = g_simple_action_new_stateful ("syntax", G_VARIANT_TYPE_STRING,
-								 g_variant_new_string ("auto"));
+                                                                 g_variant_new_string ("auto"));
     g_signal_connect (act_syntax, "activate", G_CALLBACK (on_syntax), window);
     g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (act_syntax));
   }
 
   gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
-  			 create_windows_menu (GTK_WINDOW (window)));
+                           create_windows_menu (GTK_WINDOW (window)));
 
   gtk_menu_shell_append (GTK_MENU_SHELL (menubar),
-  			 create_help_menu (GTK_WINDOW (window)));
+                           create_help_menu (GTK_WINDOW (window)));
 
   g_object_unref (xml);
 }
@@ -998,9 +1041,9 @@ GtkWidget *
 psppire_syntax_window_new (const char *encoding)
 {
   GObject *sw = g_object_new (psppire_syntax_window_get_type (),
-			      "description", _("Syntax Editor"),
-			      "encoding", encoding,
-			      NULL);
+                              "description", _("Syntax Editor"),
+                              "encoding", encoding,
+                              NULL);
 
   GApplication *app = g_application_get_default ();
   gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (sw));
@@ -1015,18 +1058,18 @@ error_dialog (GtkWindow *w, const gchar *filename,  GError *err)
 
   GtkWidget *dialog =
     gtk_message_dialog_new (w,
-			    GTK_DIALOG_DESTROY_WITH_PARENT,
-			    GTK_MESSAGE_ERROR,
-			    GTK_BUTTONS_CLOSE,
-			    _("Cannot load syntax file `%s'"),
-			    fn);
+                            GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_ERROR,
+                            GTK_BUTTONS_CLOSE,
+                            _("Cannot load syntax file `%s'"),
+                            fn);
 
   g_free (fn);
 
   g_object_set (dialog, "icon-name", "org.gnu.pspp", NULL);
 
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					    "%s", err->message);
+                                            "%s", err->message);
 
   gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -1118,10 +1161,10 @@ static void
 undo_redo_update (PsppireSyntaxWindow *window)
 {
   g_object_set (window->undo_menuitem, "enabled",
-		gtk_source_buffer_can_undo (window->buffer), NULL);
+                gtk_source_buffer_can_undo (window->buffer), NULL);
 
   g_object_set  (window->redo_menuitem, "enabled",
-		 gtk_source_buffer_can_redo (window->buffer), NULL);
+                 gtk_source_buffer_can_redo (window->buffer), NULL);
 }
 
 static void
@@ -1187,8 +1230,8 @@ draw_page (GtkPrintOperation *operation,
           PsppireSyntaxWindow *window)
 {
   gtk_source_print_compositor_draw_page (window->compositor,
-					 context,
-					 page_nr);
+                                         context,
+                                         page_nr);
 }
 
 
