@@ -43,6 +43,7 @@
 
 #include "ui/gui/dict-display.h"
 #include "ui/gui/executor.h"
+#include "ui/gui/options-dialog.h"
 #include "ui/gui/psppire-data-store.h"
 #include "ui/gui/psppire-data-window.h"
 #include "ui/gui/psppire-dict.h"
@@ -107,13 +108,13 @@ initialize (const struct init_source *is)
       break;
     case 8:
       if (! gtk_parse_args (is->argc, is->argv))
-	{
-	  perror ("Error parsing arguments");
-	  exit (1);
-	}
+        {
+          perror ("Error parsing arguments");
+          exit (1);
+        }
       break;
     case 9:
-      journal_init ();
+      options_init ();
       break;
     case 10:
       textdomain (PACKAGE);
@@ -173,9 +174,9 @@ psppire_preload_file (const gchar *file, GtkWindow *victim)
   const gchar *local_encoding = "UTF-8";
 
   struct file_handle *fh = fh_create_file (NULL,
-					   file,
-					   local_encoding,
-					   fh_default_properties ());
+                                           file,
+                                           local_encoding,
+                                           fh_default_properties ());
   const char *filename = fh_get_file_name (fh);
 
   int retval = any_reader_detect (fh, NULL);
