@@ -91,9 +91,9 @@ static GObject *psppire_var_type_dialog_constructor (GType type, guint,
 static void psppire_var_type_dialog_set_state (PsppireVarTypeDialog *);
 
 static void psppire_var_type_dialog_set_format (PsppireVarTypeDialog *dialog,
-						const struct fmt_spec *format);
+                                                struct fmt_spec format);
 
-static int find_format (const struct fmt_spec *target,
+static int find_format (struct fmt_spec target,
                         const struct fmt_spec formats[], int n_formats);
 static int find_format_type (int target, const int types[], int n_types);
 
@@ -127,7 +127,10 @@ psppire_var_type_dialog_set_property (GObject      *object,
   switch (prop_id)
     {
     case PROP_FORMAT:
-      psppire_var_type_dialog_set_format (obj, g_value_get_boxed (value));
+      {
+        const struct fmt_spec *f = g_value_get_boxed (value);
+        psppire_var_type_dialog_set_format (obj, *f);
+      }
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -156,16 +159,16 @@ psppire_var_type_dialog_get_property (GObject      *object,
 
 static void
 psppire_var_type_dialog_set_format (PsppireVarTypeDialog *dialog,
-                                    const struct fmt_spec *format)
+                                    struct fmt_spec format)
 {
-  dialog->base_format = *format;
+  dialog->base_format = format;
   psppire_var_type_dialog_set_state (dialog);
 }
 
-static const struct fmt_spec *
+static struct fmt_spec
 psppire_var_type_dialog_get_format (const PsppireVarTypeDialog *dialog)
 {
-  return &dialog->fmt_l;
+  return dialog->fmt_l;
 }
 
 static void
@@ -220,7 +223,7 @@ psppire_var_type_dialog_run (GtkWindow *parent_window,
 
   gint result = psppire_dialog_run (PSPPIRE_DIALOG (dialog));
   if (result == GTK_RESPONSE_OK)
-    *format = *psppire_var_type_dialog_get_format (dialog);
+    *format = psppire_var_type_dialog_get_format (dialog);
 
   gtk_widget_destroy (GTK_WIDGET (dialog));
 
@@ -358,13 +361,13 @@ on_active_button_change (GtkToggleButton *togglebutton,
       dialog->fmt_l.type = FMT_A;
       break;
     case BUTTON_DATE:
-      indx = find_format (&dialog->fmt_l, date_format,
+      indx = find_format (dialog->fmt_l, date_format,
                           sizeof date_format / sizeof *date_format);
       select_treeview_at_index (dialog->date_format_treeview, indx);
       dialog->fmt_l = date_format[indx];
       break;
     case BUTTON_DOLLAR:
-      indx = find_format (&dialog->fmt_l, dollar_format,
+      indx = find_format (dialog->fmt_l, dollar_format,
                           sizeof dollar_format / sizeof *dollar_format);
       select_treeview_at_index (dialog->dollar_treeview, indx);
       dialog->fmt_l = dollar_format[indx];
@@ -432,8 +435,7 @@ preview_custom (GtkWidget *w, gpointer data)
   text = gtk_entry_get_text (GTK_ENTRY (dialog->entry_width));
   dialog->fmt_l.w = atoi (text);
 
-  msg_disable ();
-  if (! fmt_check_output (&dialog->fmt_l))
+  if (! fmt_check_output (dialog->fmt_l))
     {
       gtk_label_set_text (GTK_LABEL (dialog->label_psample), "---");
       gtk_label_set_text (GTK_LABEL (dialog->label_nsample), "---");
@@ -444,18 +446,17 @@ preview_custom (GtkWidget *w, gpointer data)
       union value v;
       v.f = 1234.56;
 
-      sample_text = g_strchug (data_out (&v, NULL, &dialog->fmt_l,
+      sample_text = g_strchug (data_out (&v, NULL, dialog->fmt_l,
                                          settings_get_fmt_settings ()));
       gtk_label_set_text (GTK_LABEL (dialog->label_psample), sample_text);
       g_free (sample_text);
 
       v.f = -v.f;
-      sample_text = g_strchug (data_out (&v, NULL, &dialog->fmt_l,
+      sample_text = g_strchug (data_out (&v, NULL, dialog->fmt_l,
                                          settings_get_fmt_settings ()));
       gtk_label_set_text (GTK_LABEL (dialog->label_nsample), sample_text);
       g_free (sample_text);
     }
-  msg_enable ();
 }
 
 static gint
@@ -540,7 +541,7 @@ psppire_var_type_dialog_constructor (GType                  type,
   dialog = PSPPIRE_VAR_TYPE_DIALOG (obj);
 
   g_object_set (dialog, "help-page", "Input-and-Output-Formats",
-		"title", _("Variable Type and Format"), NULL);
+                "title", _("Variable Type and Format"), NULL);
 
   xml = builder_new ("var-type-dialog.ui");
 
@@ -551,7 +552,7 @@ psppire_var_type_dialog_constructor (GType                  type,
   dialog->active_button = -1;
 
   g_signal_connect (dialog, "delete-event",
-		    G_CALLBACK (gtk_widget_hide_on_delete), NULL);
+                    G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
   dialog->radioButton[BUTTON_NUMERIC] =
     get_widget_assert (xml,"radiobutton1");
@@ -586,7 +587,7 @@ psppire_var_type_dialog_constructor (GType                  type,
   dialog->adj_width = gtk_spin_button_get_adjustment (
     GTK_SPIN_BUTTON (dialog->entry_width));
   dialog->custom_currency_hbox = get_widget_assert (xml,
-						   "custom_currency_hbox");
+                                                   "custom_currency_hbox");
 
   dialog->dollar_window = get_widget_assert (xml, "dollar_window");
   dialog->dollar_treeview =
@@ -611,7 +612,7 @@ psppire_var_type_dialog_constructor (GType                  type,
   GtkSizeGroup *sizeGroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
   gtk_container_foreach (GTK_CONTAINER (get_widget_assert (xml, "middle_box")),
-			add_to_group, sizeGroup);
+                        add_to_group, sizeGroup);
 
 
   for (i = 0 ; i < num_BUTTONS; ++i)
@@ -620,38 +621,38 @@ psppire_var_type_dialog_constructor (GType                  type,
 
   /* Populate the date format tree view */
   dialog->date_format_treeview = GTK_TREE_VIEW (get_widget_assert (xml,
-					      "date_format_list_view"));
+                                              "date_format_list_view"));
 
   renderer = gtk_cell_renderer_text_new ();
 
   column = gtk_tree_view_column_new_with_attributes ("Title",
-						     renderer,
-						     "text",
-						     0,
-						     NULL);
+                                                     renderer,
+                                                     "text",
+                                                     0,
+                                                     NULL);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->date_format_treeview),
-			       column);
+                               column);
 
 
   list_store = gtk_list_store_new (1, G_TYPE_STRING);
 
   for (i = 0 ; i < sizeof (date_format) / sizeof (date_format[0]) ; ++i)
     {
-      const struct fmt_spec *f = &date_format[i];
+      struct fmt_spec f = date_format[i];
       gtk_list_store_append (list_store, &iter);
       gtk_list_store_set (list_store, &iter,
-                          0, fmt_date_template (f->type, f->w),
-			  -1);
+                          0, fmt_date_template (f.type, f.w),
+                          -1);
     }
 
   gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->date_format_treeview),
-			  GTK_TREE_MODEL (list_store));
+                          GTK_TREE_MODEL (list_store));
 
   g_object_unref (list_store);
 
   g_signal_connect (dialog->date_format_treeview, "cursor-changed",
-		   G_CALLBACK (set_date_format_from_treeview), dialog);
+                   G_CALLBACK (set_date_format_from_treeview), dialog);
 
 
   /* populate the dollar treeview */
@@ -659,39 +660,39 @@ psppire_var_type_dialog_constructor (GType                  type,
   renderer = gtk_cell_renderer_text_new ();
 
   column = gtk_tree_view_column_new_with_attributes ("Title",
-						     renderer,
-						     "text",
-						     0,
-						     NULL);
+                                                     renderer,
+                                                     "text",
+                                                     0,
+                                                     NULL);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->dollar_treeview),
-			       column);
+                               column);
 
 
   list_store = gtk_list_store_new (1, G_TYPE_STRING);
 
   for (i = 0 ; i < sizeof (dollar_format)/sizeof (dollar_format[0]) ; ++i)
     {
-      char *template = settings_dollar_template (&dollar_format[i]);
+      char *template = settings_dollar_template (dollar_format[i]);
       gtk_list_store_append (list_store, &iter);
       gtk_list_store_set (list_store, &iter,
                           0, template,
-			  -1);
+                          -1);
       free (template);
     }
 
   gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->dollar_treeview),
-			  GTK_TREE_MODEL (list_store));
+                          GTK_TREE_MODEL (list_store));
 
   g_object_unref (list_store);
 
   g_signal_connect (dialog->dollar_treeview,
-		   "cursor-changed",
-		   G_CALLBACK (set_dollar_format_from_treeview), dialog);
+                   "cursor-changed",
+                   G_CALLBACK (set_dollar_format_from_treeview), dialog);
 
   g_signal_connect_swapped (dialog->dollar_treeview,
-		   "cursor-changed",
-		   G_CALLBACK (update_width_decimals), dialog);
+                   "cursor-changed",
+                   G_CALLBACK (update_width_decimals), dialog);
 
 
   /* populate the custom treeview */
@@ -699,13 +700,13 @@ psppire_var_type_dialog_constructor (GType                  type,
   renderer = gtk_cell_renderer_text_new ();
 
   column = gtk_tree_view_column_new_with_attributes ("Title",
-						     renderer,
-						     "text",
-						     0,
-						     NULL);
+                                                     renderer,
+                                                     "text",
+                                                     0,
+                                                     NULL);
 
   gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->custom_treeview),
-			       column);
+                               column);
 
 
   list_store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -716,23 +717,23 @@ psppire_var_type_dialog_constructor (GType                  type,
       gtk_list_store_append (list_store, &iter);
       gtk_list_store_set (list_store, &iter,
                           0, fmt_name (cc_fmts[i]),
-			  -1);
+                          -1);
     }
 
   gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->custom_treeview),
-			  GTK_TREE_MODEL (list_store));
+                          GTK_TREE_MODEL (list_store));
 
   g_object_unref (list_store);
 
 
   g_signal_connect (dialog->custom_treeview,
-		   "cursor-changed",
-		   G_CALLBACK (set_custom_format_from_treeview), dialog);
+                   "cursor-changed",
+                   G_CALLBACK (set_custom_format_from_treeview), dialog);
 
 
   g_signal_connect (dialog->custom_treeview,
-		   "cursor-changed",
-		   G_CALLBACK (preview_custom), dialog);
+                   "cursor-changed",
+                   G_CALLBACK (preview_custom), dialog);
 
 
   g_signal_connect (dialog->entry_width, "changed",
@@ -741,13 +742,13 @@ psppire_var_type_dialog_constructor (GType                  type,
                     G_CALLBACK (on_decimals_changed), dialog);
 
   g_signal_connect (dialog->entry_width,
-		   "changed",
-		   G_CALLBACK (preview_custom), dialog);
+                   "changed",
+                   G_CALLBACK (preview_custom), dialog);
 
 
   g_signal_connect (dialog->entry_decimals,
-		   "changed",
-		   G_CALLBACK (preview_custom), dialog);
+                   "changed",
+                   G_CALLBACK (preview_custom), dialog);
 
   }
 
@@ -764,7 +765,7 @@ static void
 var_type_dialog_set_active_button (PsppireVarTypeDialog *dialog, gint b)
 {
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->radioButton[b]),
-			       TRUE);
+                               TRUE);
 }
 
 
@@ -780,13 +781,13 @@ select_treeview_at_index (GtkTreeView *treeview, int index)
 }
 
 static int
-find_format (const struct fmt_spec *target,
+find_format (struct fmt_spec target,
              const struct fmt_spec formats[], int n_formats)
 {
   int i;
 
   for (i = 0; i < n_formats; i++)
-    if (fmt_equal (target, &formats[i]))
+    if (fmt_equal (target, formats[i]))
       return i;
 
   return 0;
