@@ -139,20 +139,28 @@ main (int argc, char **argv)
       int result = cmd_parse (lexer, session_active_dataset (the_session));
 
       if (result == CMD_EOF || result == CMD_FINISH)
-	break;
+        break;
       else if (cmd_result_is_failure (result) && lex_token (lexer) != T_STOP)
         {
-          if (lex_get_error_mode (lexer) == LEX_ERROR_STOP)
+          switch (lex_get_error_mode (lexer))
             {
+            case LEX_ERROR_STOP:
               msg (MW, _("Error encountered while ERROR=STOP is effective."));
               lex_discard_noninteractive (lexer);
-            }
-          else if (result == CMD_CASCADING_FAILURE
-                   && lex_get_error_mode (lexer) != LEX_ERROR_TERMINAL)
-            {
-              msg (SE, _("Stopping syntax file processing here to avoid "
-                         "a cascade of dependent command failures."));
-              lex_discard_noninteractive (lexer);
+              break;
+
+            case LEX_ERROR_CONTINUE:
+              if (result == CMD_CASCADING_FAILURE)
+                {
+                  msg (SE, _("Stopping syntax file processing here to avoid "
+                             "a cascade of dependent command failures."));
+                  lex_discard_noninteractive (lexer);
+                }
+              break;
+
+            case LEX_ERROR_TERMINAL:
+            case LEX_ERROR_IGNORE:
+              break;
             }
         }
 
@@ -247,7 +255,18 @@ add_syntax_reader (struct lexer *lexer, const char *file_name,
 {
   struct lex_reader *reader;
 
-  reader = (!strcmp (file_name, "-") && isatty (STDIN_FILENO)
+  bool interactive;
+  if (!strcmp (file_name, "-"))
+    {
+      /* This allows the testsuite to simulate interactive behavior by setting
+         PSPP_INTERACTIVE=1 in the environment. */
+      const char *env = getenv ("PSPP_INTERACTIVE");
+      interactive = env ? strcmp (env, "0") : isatty (STDIN_FILENO);
+    }
+  else
+    interactive = false;
+
+  reader = (interactive
             ? terminal_reader_create ()
             : lex_reader_for_file (file_name, encoding, syntax_mode,
                                    LEX_ERROR_CONTINUE));
