@@ -137,12 +137,18 @@ configure_drivers (int width, int length UNUSED, int min_break)
   string_map_insert (&options, "trim", "true");
   register_driver (&options, "%s.pdf", output_base);
 
+  /* Render to <base>-paged.pdf. */
+  register_driver (&options, "%s-paged.pdf", output_base);
+
+  /* Render to <base>.txt. */
   string_map_insert (&options, "box", "unicode");
   register_driver (&options, "%s.txt", output_base);
 
+  /* Render to <base>-ascii.txt. */
   string_map_insert (&options, "box", "ascii");
   register_driver (&options, "%s-ascii.txt", output_base);
 
+  /* Render additional versions. */
   register_driver (&options, "%s.csv", output_base);
   register_driver (&options, "%s.odt", output_base);
   register_driver (&options, "%s.spv", output_base);
@@ -586,8 +592,8 @@ read_value_option (struct lexer *lexer, const struct pivot_table *pt,
 
       if (ok)
         {
-          if (!fmt_check_output (&fmt)
-              || !fmt_check_type_compat (&fmt, VAL_NUMERIC))
+          if (!fmt_check_output (fmt)
+              || !fmt_check_type_compat (fmt, VAL_NUMERIC))
             exit (1);
 
           value->numeric.format = fmt;
@@ -661,7 +667,7 @@ read_value_option (struct lexer *lexer, const struct pivot_table *pt,
       return;
     }
 
-  lex_error (lexer, "Expecting valid value option");
+  lex_error (lexer, "Syntax error expecting valid value option.");
   exit (1);
 }
 
@@ -826,7 +832,7 @@ read_stroke (struct lexer *lexer)
     if (lex_match_id (lexer, table_stroke_to_string (stroke)))
       return stroke;
 
-  lex_error (lexer, "expecting stroke");
+  lex_error (lexer, "Syntax error expecting stroke.");
   exit (1);
 }
 
